@@ -11,10 +11,11 @@ fi
 OS_AUTH_TOKEN=$(openstack token issue | grep ' id ' | awk '{print $4}')
 IRONIC_URL="http://127.0.0.1:6385"
 
-IRONIC_API_VERSION="1.37"
+IRONIC_API_VERSION="1.55"
 
 export OS_AUTH_TOKEN IRONIC_URL
 
+DOC_BIOS_UUID="dff29d23-1ded-43b4-8ae1-5eebb3e30de1"
 DOC_CHASSIS_UUID="dff29d23-1ded-43b4-8ae1-5eebb3e30de1"
 DOC_NODE_UUID="6d85703a-565d-469a-96ce-30b6de53079d"
 DOC_DYNAMIC_NODE_UUID="2b045129-a906-46af-bc1a-092b294b3428"
@@ -26,6 +27,8 @@ DOC_PROVISION_UPDATED_AT="2016-08-18T22:28:49.946416+00:00"
 DOC_CREATED_AT="2016-08-18T22:28:48.643434+11:11"
 DOC_UPDATED_AT="2016-08-18T22:28:49.653974+00:00"
 DOC_IRONIC_CONDUCTOR_HOSTNAME="897ab1dad809"
+DOC_ALLOCATION_UUID="3bf138ba-6d71-44e7-b6a1-ca9cac17103e"
+DOC_DEPLOY_TEMPLATE_UUID="bbb45f41-d4bc-4307-8d1d-32f95ce1e920"
 
 function GET {
     # GET $RESOURCE
@@ -166,13 +169,37 @@ GET v1/nodes > nodes-list-response.json
 GET v1/nodes/detail > nodes-list-details-response.json
 GET v1/nodes/$NID > node-show-response.json
 
-# Put the Node in maintenance mode, then continue doing everything else
-PUT v1/nodes/$NID/maintenance node-maintenance-request.json
-
 # Node traits
 PUT v1/nodes/$NID/traits node-set-traits-request.json
 GET v1/nodes/$NID/traits > node-traits-list-response.json
 
+############
+# ALLOCATIONS
+
+POST v1/allocations allocation-create-request.json > allocation-create-response.json
+AID=$(cat allocation-create-response.json | grep '"uuid"' | sed 's/.*"\([0-9a-f\-]*\)",*/\1/')
+if [ "$AID" == "" ]; then
+    exit 1
+else
+    echo "Allocation created. UUID: $AID"
+fi
+
+# Create a failed allocation for listing
+POST v1/allocations allocation-create-request-2.json
+
+# Poor man's wait_for_allocation
+sleep 1
+
+GET v1/allocations > allocations-list-response.json
+GET v1/allocations/$AID > allocation-show-response.json
+GET v1/nodes/$NID/allocation > node-allocation-show-response.json
+
+############
+# NODES - MAINTENANCE
+
+# Do this after allocation API to be able to create successful allocations
+PUT v1/nodes/$NID/maintenance node-maintenance-request.json
+
 ############
 # PORTGROUPS
 
@@ -246,7 +273,7 @@ GET v1/lookup?node_uuid=$NID > lookup-node-response.json
 # and the node's driver is "fake", to avoid potential races
 # with internal processes that lock the Node
 
-# this corrects an intentional ommission in some of the samples
+# this corrects an intentional omission in some of the samples
 PATCH v1/nodes/$NID node-update-driver-info-request.json > node-update-driver-info-response.json
 
 GET v1/nodes/$NID/management/boot_device/supported > node-get-supported-boot-devices-response.json
@@ -300,9 +327,25 @@ GET v1/nodes/$NID/volume/connectors?detail=True > node-volume-connector-detail-r
 GET v1/nodes/$NID/volume/targets > node-volume-target-list-response.json
 GET v1/nodes/$NID/volume/targets?detail=True > node-volume-target-detail-response.json
 
+##################
+# DEPLOY TEMPLATES
+
+POST v1/deploy_templates deploy-template-create-request.json > deploy-template-create-response.json
+DTID=$(cat deploy-template-create-response.json | grep '"uuid"' | sed 's/.*"\([0-9a-f\-]*\)",*/\1/')
+if [ "$DTID" == "" ]; then
+    exit 1
+else
+    echo "Deploy template created. UUID: $DTID"
+fi
+
+GET v1/deploy_templates > deploy-template-list-response.json
+GET v1/deploy_templates?detail=True > deploy-template-detail-response.json
+GET v1/deploy_templates/$DTID > deploy-template-show-response.json
+PATCH v1/deploy_templates/$DTID deploy-template-update-request.json > deploy-template-update-response.json
 
 #####################
 # Replace automatically generated UUIDs by already used in documentation
+sed -i "s/$BID/$DOC_BIOS_UUID/" *.json
 sed -i "s/$CID/$DOC_CHASSIS_UUID/" *.json
 sed -i "s/$NID/$DOC_NODE_UUID/" *.json
 sed -i "s/$DNID/$DOC_DYNAMIC_NODE_UUID/" *.json
@@ -310,7 +353,15 @@ sed -i "s/$PID/$DOC_PORT_UUID/" *.json
 sed -i "s/$PGID/$DOC_PORTGROUP_UUID/" *.json
 sed -i "s/$VCID/$DOC_VOL_CONNECTOR_UUID/" *.json
 sed -i "s/$VTID/$DOC_VOL_TARGET_UUID/" *.json
+sed -i "s/$AID/$DOC_ALLOCATION_UUID/" *.json
+sed -i "s/$DTID/$DOC_DEPLOY_TEMPLATE_UUID/" *.json
 sed -i "s/$(hostname)/$DOC_IRONIC_CONDUCTOR_HOSTNAME/" *.json
 sed -i "s/created_at\": \".*\"/created_at\": \"$DOC_CREATED_AT\"/" *.json
 sed -i "s/updated_at\": \".*\"/updated_at\": \"$DOC_UPDATED_AT\"/" *.json
 sed -i "s/provision_updated_at\": \".*\"/provision_updated_at\": \"$DOC_PROVISION_UPDATED_AT\"/" *.json
+
+##########
+# Clean up
+
+openstack baremetal node maintenance set $NID
+openstack baremetal node delete $NID
