@@ -35,7 +35,7 @@ def _error_about_sqlite_usage():
         # TODO(TheJulia): Make this a hard error in C*
         LOG.error('We have detected the API is being launched with a SQLite '
                   'database backend. This is unsupported, and will be a hard '
-                  'error in the future. This is becaues multi-process use of '
+                  'error in the future. This is because multi-process use of '
                   'a single SQLite database is problematic in terms of '
                   'locking. A single process ironic model exists for use with '
                   'SQLite.')
