@@ -616,7 +616,29 @@ RELEASE_MAPPING = {
             'FirmwareComponent': ['1.0'],
         }
     },
-    'master': {
+    '23.0': {
+        'api': '1.87',
+        'rpc': '1.58',
+        'objects': {
+            'Allocation': ['1.1'],
+            'BIOSSetting': ['1.1'],
+            'Node': ['1.40', '1.39', '1.38', '1.37'],
+            'NodeHistory': ['1.0'],
+            'NodeInventory': ['1.0'],
+            'Conductor': ['1.3'],
+            'Chassis': ['1.3'],
+            'Deployment': ['1.0'],
+            'DeployTemplate': ['1.1'],
+            'Port': ['1.11'],
+            'Portgroup': ['1.5'],
+            'Trait': ['1.0'],
+            'TraitList': ['1.0'],
+            'VolumeConnector': ['1.0'],
+            'VolumeTarget': ['1.0'],
+            'FirmwareComponent': ['1.0'],
+        }
+    },
+    '23.1': {
         'api': '1.88',
         'rpc': '1.58',
         'objects': {
@@ -638,6 +660,72 @@ RELEASE_MAPPING = {
             'FirmwareComponent': ['1.0'],
         }
     },
+    '24.0': {
+        'api': '1.89',
+        'rpc': '1.59',
+        'objects': {
+            'Allocation': ['1.1'],
+            'BIOSSetting': ['1.1'],
+            'Node': ['1.40', '1.39', '1.38', '1.37'],
+            'NodeHistory': ['1.0'],
+            'NodeInventory': ['1.0'],
+            'Conductor': ['1.3'],
+            'Chassis': ['1.3'],
+            'Deployment': ['1.0'],
+            'DeployTemplate': ['1.1'],
+            'Port': ['1.11'],
+            'Portgroup': ['1.5'],
+            'Trait': ['1.0'],
+            'TraitList': ['1.0'],
+            'VolumeConnector': ['1.0'],
+            'VolumeTarget': ['1.0'],
+            'FirmwareComponent': ['1.0'],
+        }
+    },
+    '24.1': {
+        'api': '1.90',
+        'rpc': '1.59',
+        'objects': {
+            'Allocation': ['1.1'],
+            'BIOSSetting': ['1.1'],
+            'Node': ['1.40', '1.39', '1.38', '1.37'],
+            'NodeHistory': ['1.0'],
+            'NodeInventory': ['1.0'],
+            'Conductor': ['1.3'],
+            'Chassis': ['1.3'],
+            'Deployment': ['1.0'],
+            'DeployTemplate': ['1.1'],
+            'Port': ['1.11'],
+            'Portgroup': ['1.5'],
+            'Trait': ['1.0'],
+            'TraitList': ['1.0'],
+            'VolumeConnector': ['1.0'],
+            'VolumeTarget': ['1.0'],
+            'FirmwareComponent': ['1.0'],
+        }
+    },
+    'master': {
+        'api': '1.90',
+        'rpc': '1.59',
+        'objects': {
+            'Allocation': ['1.1'],
+            'BIOSSetting': ['1.1'],
+            'Node': ['1.40', '1.39', '1.38', '1.37'],
+            'NodeHistory': ['1.0'],
+            'NodeInventory': ['1.0'],
+            'Conductor': ['1.3'],
+            'Chassis': ['1.3'],
+            'Deployment': ['1.0'],
+            'DeployTemplate': ['1.1'],
+            'Port': ['1.11'],
+            'Portgroup': ['1.5'],
+            'Trait': ['1.0'],
+            'TraitList': ['1.0'],
+            'VolumeConnector': ['1.0'],
+            'VolumeTarget': ['1.0'],
+            'FirmwareComponent': ['1.0'],
+        }
+    },
 }
 
 # NOTE(xek): Assign each named release to the appropriate semver.
@@ -655,6 +743,8 @@ RELEASE_MAPPING['yoga'] = RELEASE_MAPPING['20.1']
 RELEASE_MAPPING['zed'] = RELEASE_MAPPING['21.1']
 RELEASE_MAPPING['antelope'] = RELEASE_MAPPING['21.4']
 RELEASE_MAPPING['2023.1'] = RELEASE_MAPPING['21.4']
+RELEASE_MAPPING['2023.2'] = RELEASE_MAPPING['23.0']
+RELEASE_MAPPING['2024.1'] = RELEASE_MAPPING['24.1']
 
 # List of available versions with named versions first; 'master' is excluded.
 RELEASE_VERSIONS = sorted(set(RELEASE_MAPPING) - {'master'}, reverse=True)
