@@ -13,17 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import cfg
 import oslo_messaging as messaging
 from oslo_messaging.rpc import dispatcher
 from osprofiler import profiler
 
 from ironic.common import context as ironic_context
 from ironic.common import exception
+from ironic.conf import CONF
 
 
-CONF = cfg.CONF
-
 TRANSPORT = None
 NOTIFICATION_TRANSPORT = None
 SENSORS_NOTIFIER = None
@@ -33,6 +31,9 @@ ALLOWED_EXMODS = [
     exception.__name__,
 ]
 EXTRA_EXMODS = []
+GLOBAL_MANAGER = None
+
+MANAGER_TOPIC = 'ironic.conductor_manager'
 
 
 def init(conf):
@@ -53,10 +54,10 @@ def init(conf):
                                                 serializer=serializer,
                                                 driver='noop')
     else:
-        VERSIONED_NOTIFIER = messaging.Notifier(NOTIFICATION_TRANSPORT,
-                                                serializer=serializer,
-                                                topics=['ironic_versioned_'
-                                                        'notifications'])
+        VERSIONED_NOTIFIER = messaging.Notifier(
+            NOTIFICATION_TRANSPORT,
+            serializer=serializer,
+            topics=CONF.versioned_notifications_topics)
 
 
 def cleanup():
@@ -121,10 +122,9 @@ def get_transport_url(url_str=None):
 def get_client(target, version_cap=None, serializer=None):
     assert TRANSPORT is not None
     serializer = RequestContextSerializer(serializer)
-    return messaging.RPCClient(TRANSPORT,
-                               target,
-                               version_cap=version_cap,
-                               serializer=serializer)
+    return messaging.get_rpc_client(
+        TRANSPORT, target, version_cap=version_cap,
+        serializer=serializer)
 
 
 def get_server(target, endpoints, serializer=None):
@@ -150,3 +150,10 @@ def get_versioned_notifier(publisher_id=None):
     assert VERSIONED_NOTIFIER is not None
     assert publisher_id is not None
     return VERSIONED_NOTIFIER.prepare(publisher_id=publisher_id)
+
+
+def set_global_manager(manager):
+    global GLOBAL_MANAGER
+    if GLOBAL_MANAGER is not None and manager is not None:
+        raise RuntimeError("An attempt to set a global manager twice")
+    GLOBAL_MANAGER = manager
