@@ -102,6 +102,7 @@ raised in the background thread.):
 
 import copy
 import functools
+import traceback
 
 import futurist
 from oslo_config import cfg
@@ -141,6 +142,10 @@ def require_exclusive_lock(f):
         else:
             task = args[0]
         if task.shared:
+            LOG.error("Callable %(func)s expected an exclusive lock, got "
+                      "a shared task for node %(node)s. Traceback:\n%(tb)s",
+                      {'func': f.__qualname__, 'node': task.node.uuid,
+                       'tb': ''.join(traceback.format_stack())})
             raise exception.ExclusiveLockRequired()
         # NOTE(lintan): This is a workaround to set the context of async tasks,
         # which should contain an exclusive lock.
@@ -522,7 +527,8 @@ class TaskManager(object):
             self.release_resources()
 
     def process_event(self, event, callback=None, call_args=None,
-                      call_kwargs=None, err_handler=None, target_state=None):
+                      call_kwargs=None, err_handler=None, target_state=None,
+                      last_error=None):
         """Process the given event for the task's current state.
 
         :param event: the name of the event to process
@@ -535,6 +541,8 @@ class TaskManager(object):
                 prev_target_state)
         :param target_state: if specified, the target provision state for the
                node. Otherwise, use the target state from the fsm
+        :param last_error: last error to set on the node together with
+               the state transition.
         :raises: InvalidState if the event is not allowed by the associated
                  state machine
         """
@@ -567,13 +575,15 @@ class TaskManager(object):
 
         # set up the async worker
         if callback:
-            # clear the error if we're going to start work in a callback
-            self.node.last_error = None
+            # update the error if we're going to start work in a callback
+            self.node.last_error = last_error
             if call_args is None:
                 call_args = ()
             if call_kwargs is None:
                 call_kwargs = {}
             self.spawn_after(callback, *call_args, **call_kwargs)
+        elif last_error is not None:
+            self.node.last_error = last_error
 
         # publish the state transition by saving the Node
         self.node.save()
@@ -599,6 +609,14 @@ class TaskManager(object):
             # emitted at __exit__().
             self._saved_node = self.node
 
+    def resume_cleaning(self):
+        """A helper to resume cleaning with the right target state."""
+        if self.node.target_provision_state == states.MANAGEABLE:
+            target_state = states.MANAGEABLE
+        else:
+            target_state = None
+        self.process_event('resume', target_state=target_state)
+
     def __enter__(self):
         return self
 
