@@ -101,15 +101,16 @@ opts = [
                                     'from the Object Storage service.')),
                         ('http', _('IPA ramdisk retrieves instance image '
                                    'from HTTP service served at conductor '
-                                   'nodes.'))],
-               default='swift',
+                                   'nodes.')),
+                        ('local', _('Same as "http", but HTTP images '
+                                    'are also cached locally, converted '
+                                    'and served from the conductor'))],
+               default='http',
                mutable=True,
                help=_('Specifies whether direct deploy interface should try '
                       'to use the image source directly or if ironic should '
                       'cache the image on the conductor and serve it from '
-                      'ironic\'s own http server. This option takes effect '
-                      'only when instance image is provided from the Image '
-                      'service.')),
+                      'ironic\'s own http server.')),
     cfg.IntOpt('command_timeout',
                default=60,
                mutable=True,
@@ -143,6 +144,31 @@ opts = [
                default=10,
                help=_('Wait time in seconds between attempts for validating '
                       'Neutron agent status.')),
+    cfg.BoolOpt('require_tls',
+                default=False,
+                mutable=True,
+                help=_('If set to True, callback URLs without https:// will '
+                       'be rejected by the conductor.')),
+    cfg.StrOpt('certificates_path',
+               default='/var/lib/ironic/certificates',
+               help=_('Path to store auto-generated TLS certificates used to '
+                      'validate connections to the ramdisk.')),
+    cfg.StrOpt('verify_ca',
+               default='True',
+               help=_('Path to the TLS CA to validate connection to the '
+                      'ramdisk. Set to True to use the system default CA '
+                      'storage. Set to False to disable validation. Ignored '
+                      'when automatic TLS setup is used.')),
+    cfg.StrOpt('api_ca_file',
+               help=_('Path to the TLS CA that is used to start the bare '
+                      'metal API. In some boot methods this file can be '
+                      'passed to the ramdisk.')),
+    cfg.BoolOpt('allow_md5_checksum',
+                default=True,
+                help=_('When enabled, the agent will be notified it is '
+                       'permitted to consider MD5 checksums. This option '
+                       'is expected to change to a default of False in a '
+                       '2024 release of Ironic.')),
 ]
 
 
