@@ -192,6 +192,10 @@ class DracRedfishPower(redfish_power.RedfishPower):
 class DracWSManPower(base.PowerInterface):
     """Interface for power-related actions."""
 
+    # NOTE(TheJulia): Deprecating November 2023 in favor of Redfish
+    # and due to a lack of active driver maintenance.
+    supported = False
+
     def get_properties(self):
         """Return the properties of the interface."""
         return drac_common.COMMON_PROPERTIES
