@@ -24,6 +24,7 @@ from ironic.drivers import base
 from ironic.drivers.modules.drac import bios as drac_bios
 from ironic.drivers.modules.drac import common as drac_common
 from ironic.drivers.modules.drac import job as drac_job
+from ironic.drivers.modules.redfish import vendor as redfish_vendor
 
 LOG = logging.getLogger(__name__)
 
@@ -33,6 +34,10 @@ METRICS = metrics_utils.get_metrics_logger(__name__)
 class DracWSManVendorPassthru(base.VendorInterface):
     """Interface for DRAC specific methods."""
 
+    # NOTE(TheJulia): Deprecating November 2023 in favor of Redfish
+    # and due to a lack of active driver maintenance.
+    supported = False
+
     def get_properties(self):
         """Return the properties of the interface."""
         return drac_common.COMMON_PROPERTIES
@@ -186,6 +191,14 @@ class DracVendorPassthru(DracWSManVendorPassthru):
     """
 
     def __init__(self):
+        super(DracVendorPassthru, self).__init__()
         LOG.warning("Vendor passthru interface 'idrac' is deprecated and may "
                     "be removed in a future release. Use 'idrac-wsman' "
                     "instead.")
+
+
+class DracRedfishVendorPassthru(redfish_vendor.RedfishVendorPassthru):
+    """iDRAC Redfish interface for vendor_passthru.
+
+    Use the Redfish implementation for vendor passthru.
+    """
