@@ -181,6 +181,9 @@ class FakeVendorA(base.VendorInterface):
                 raise exception.MissingParameterValue(_(
                     "Parameter 'bar' not passed to method 'first_method'."))
 
+    # NOTE(TheJulia): As an example, it is advisable to assign
+    # parameters from **kwargs, and then perform handling on
+    # the needful necessary from there.
     @base.passthru(['POST'],
                    description=_("Test if the value of bar is baz"))
     def first_method(self, task, http_method, bar):
@@ -221,6 +224,21 @@ class FakeVendorB(base.VendorInterface):
         sleep(CONF.fake.vendor_delay)
         return True if bar == 'woof' else False
 
+    @base.service_step(requires_ramdisk=False)
+    @base.clean_step(priority=1)
+    @base.passthru(['POST'],
+                   description=_("Test pass-through to wait."))
+    def log_passthrough(self, task, **kwargs):
+        LOG.debug('Test method test_passhtrough_method called with '
+                  'arguments %s.', kwargs)
+        sleep(CONF.fake.vendor_delay)
+        # NOTE(TheJulia): Step methods invoked via an API *cannot*
+        # have return values
+
+    @base.service_step()
+    def trigger_servicewait(self, task, **kwargs):
+        return states.SERVICEWAIT
+
 
 class FakeConsole(base.ConsoleInterface):
     """Example implementation of a simple console interface."""
@@ -443,3 +461,26 @@ class FakeRescue(base.RescueInterface):
     def unrescue(self, task):
         sleep(CONF.fake.rescue_delay)
         return states.ACTIVE
+
+
+class FakeFirmware(base.FirmwareInterface):
+    """Example implementation of a simple firmware interface."""
+
+    def get_properties(self):
+        return {}
+
+    def validate(self, task):
+        pass
+
+    @base.clean_step(priority=0, argsinfo={
+        'settings': {'description': ('List of Firmware components, each item '
+                     'needs to contain a dictionary with name/value pairs'),
+                     'required': True}})
+    def update(self, task, settings):
+        LOG.debug('Calling update clean step with settings %s.',
+                  settings)
+        sleep(CONF.fake.firmware_delay)
+
+    def cache_firmware_components(self, task):
+        sleep(CONF.fake.firmware_delay)
+        pass
