@@ -65,9 +65,7 @@ class ImageCache(object):
         if master_dir is not None:
             fileutils.ensure_tree(master_dir)
 
-    def fetch_image(self, href, dest_path, ctx=None, force_raw=True,
-                    expected_format=None, expected_checksum=None,
-                    expected_checksum_algo=None):
+    def fetch_image(self, href, dest_path, ctx=None, force_raw=True):
         """Fetch image by given href to the destination path.
 
         Does nothing if destination path exists and is up to date with cache
@@ -82,33 +80,16 @@ class ImageCache(object):
         :param ctx: context
         :param force_raw: boolean value, whether to convert the image to raw
                           format
-        :param expected_format: The expected image format.
-        :param expected_checksum: The expected image checksum
-        :param expected_checksum_algo: The expected image checksum algorithm,
-                                       if needed/supplied.
         """
         img_download_lock_name = 'download-image'
         if self.master_dir is None:
             # NOTE(ghe): We don't share images between instances/hosts
-            # NOTE(TheJulia): These is a weird code path, because master_dir
-            # has to be None, which by default it never should be unless
-            # an operator forces it to None, which is a path we just never
-            # expect.
-            # TODO(TheJulia): This may be dead-ish code and likely needs
-            # to be removed. Likely originated *out* of just the iscsi
-            # deployment interface and local image caching.
             if not CONF.parallel_image_downloads:
                 with lockutils.lock(img_download_lock_name):
-                    _fetch(ctx, href, dest_path, force_raw,
-                           expected_format=expected_format,
-                           expected_checksum=expected_checksum,
-                           expected_checksum_algo=expected_checksum_algo)
+                    _fetch(ctx, href, dest_path, force_raw)
             else:
                 with _concurrency_semaphore:
-                    _fetch(ctx, href, dest_path, force_raw,
-                           expected_format=expected_format,
-                           expected_checksum=expected_checksum,
-                           expected_checksum_algo=expected_checksum_algo)
+                    _fetch(ctx, href, dest_path, force_raw)
             return
 
         # TODO(ghe): have hard links and counts the same behaviour in all fs
@@ -159,18 +140,13 @@ class ImageCache(object):
                      {'href': href})
             self._download_image(
                 href, master_path, dest_path, img_info,
-                ctx=ctx, force_raw=force_raw,
-                expected_format=expected_format,
-                expected_checksum=expected_checksum,
-                expected_checksum_algo=expected_checksum_algo)
+                ctx=ctx, force_raw=force_raw)
 
         # NOTE(dtantsur): we increased cache size - time to clean up
         self.clean_up()
 
     def _download_image(self, href, master_path, dest_path, img_info,
-                        ctx=None, force_raw=True, expected_format=None,
-                        expected_checksum=None,
-                        expected_checksum_algo=None):
+                        ctx=None, force_raw=True):
         """Download image by href and store at a given path.
 
         This method should be called with uuid-specific lock taken.
@@ -182,9 +158,6 @@ class ImageCache(object):
         :param ctx: context
         :param force_raw: boolean value, whether to convert the image to raw
                           format
-        :param expected_format: The expected original format for the image.
-        :param expected_checksum: The expected image checksum.
-        :param expected_checksum_algo: The expected image checksum algorithm.
         :raise ImageDownloadFailed: when the image cache and the image HTTP or
                                     TFTP location are on different file system,
                                     causing hard link to fail.
@@ -196,9 +169,7 @@ class ImageCache(object):
 
         try:
             with _concurrency_semaphore:
-                _fetch(ctx, href, tmp_path, force_raw, expected_format,
-                       expected_checksum=expected_checksum,
-                       expected_checksum_algo=expected_checksum_algo)
+                _fetch(ctx, href, tmp_path, force_raw)
 
             if img_info.get('no_cache'):
                 LOG.debug("Caching is disabled for image %s", href)
@@ -362,59 +333,34 @@ def _free_disk_space_for(path):
     return stat.f_frsize * stat.f_bavail
 
 
-def _fetch(context, image_href, path, force_raw=False, expected_format=None,
-           expected_checksum=None, expected_checksum_algo=None):
+def _fetch(context, image_href, path, force_raw=False):
     """Fetch image and convert to raw format if needed."""
     path_tmp = "%s.part" % path
-    images.fetch(context, image_href, path_tmp, force_raw=False,
-                 checksum=expected_checksum,
-                 checksum_algo=expected_checksum_algo)
-    # By default, the image format is unknown
-    image_format = None
-    disable_dii = CONF.conductor.disable_deep_image_inspection
-    if not disable_dii:
-        if not expected_format:
-            # Call of last resort to check the image format. Caching other
-            # artifacts like kernel/ramdisks are not going to have an expected
-            # format known even if they are not passed to qemu-img.
-            remote_image_format = images.image_show(
-                context,
-                image_href).get('disk_format')
-        else:
-            remote_image_format = expected_format
-        image_format = images.safety_check_image(path_tmp)
-        images.check_if_image_format_is_permitted(
-            image_format, remote_image_format)
-
+    if os.path.exists(path_tmp):
+        LOG.warning("%s exist, assuming it's stale", path_tmp)
+        os.remove(path_tmp)
+    images.fetch(context, image_href, path_tmp, force_raw=False)
     # Notes(yjiang5): If glance can provide the virtual size information,
     # then we can firstly clean cache and then invoke images.fetch().
-    if (force_raw
-            and ((disable_dii
-                 and images.force_raw_will_convert(image_href, path_tmp))
-                 or (not disable_dii and image_format != 'raw'))):
-        # NOTE(TheJulia): What is happening here is the rest of the logic
-        # is hinged on force_raw, but also we don't need to take the entire
-        # path *if* the image on disk is *already* raw. Depending on settings,
-        # the path differs slightly because if we have deep image inspection,
-        # we can just rely upon the inspection image format, otherwise we
-        # need to ask the image format.
-
-        required_space = images.converted_size(path_tmp, estimate=False)
-        directory = os.path.dirname(path_tmp)
-        try:
-            _clean_up_caches(directory, required_space)
-        except exception.InsufficientDiskSpace:
-
-            # try again with an estimated raw size instead of the full size
-            required_space = images.converted_size(path_tmp, estimate=True)
+    if force_raw:
+        if images.force_raw_will_convert(image_href, path_tmp):
+            required_space = images.converted_size(path_tmp, estimate=False)
+            directory = os.path.dirname(path_tmp)
             try:
                 _clean_up_caches(directory, required_space)
             except exception.InsufficientDiskSpace:
-                LOG.error('Not enough space for estimated image size. '
-                          'Consider lowering '
-                          '[DEFAULT]raw_image_growth_factor=%s',
-                          CONF.raw_image_growth_factor)
-                raise
+
+                # try again with an estimated raw size instead of the full size
+                required_space = images.converted_size(path_tmp, estimate=True)
+                try:
+                    _clean_up_caches(directory, required_space)
+                except exception.InsufficientDiskSpace:
+                    LOG.warning('Not enough space for estimated image size. '
+                                'Consider lowering '
+                                '[DEFAULT]raw_image_growth_factor=%s',
+                                CONF.raw_image_growth_factor)
+                    raise
+
         images.image_to_raw(image_href, path, path_tmp)
     else:
         os.rename(path_tmp, path)
