@@ -45,6 +45,17 @@ class PXEBoot(pxe_base.PXEBaseMixin, base.BootInterface):
         pxe_utils.place_loaders_for_boot(CONF.pxe.tftp_root)
 
 
+class HttpBoot(pxe_base.PXEBaseMixin, base.BootInterface):
+
+    http_boot_enabled = True
+
+    capabilities = ['ramdisk_boot', 'pxe_boot']
+
+    def __init__(self):
+        pxe_utils.place_common_config()
+        pxe_utils.place_loaders_for_boot(CONF.deploy.http_root)
+
+
 class PXEAnacondaDeploy(agent_base.AgentBaseMixin, agent_base.HeartbeatMixin,
                         base.DeployInterface):
 
