@@ -15,8 +15,8 @@ from urllib.parse import urlparse
 
 from ironic_lib import metrics_utils
 from oslo_log import log
-from oslo_utils import importutils
 from oslo_utils import timeutils
+import sushy
 
 from ironic.common import exception
 from ironic.common.i18n import _
@@ -34,8 +34,6 @@ LOG = log.getLogger(__name__)
 
 METRICS = metrics_utils.get_metrics_logger(__name__)
 
-sushy = importutils.try_import('sushy')
-
 
 class RedfishFirmware(base.FirmwareInterface):
 
@@ -48,13 +46,6 @@ class RedfishFirmware(base.FirmwareInterface):
         }
     }
 
-    def __init__(self):
-        super(RedfishFirmware, self).__init__()
-        if sushy is None:
-            raise exception.DriverLoadError(
-                driver='redfish',
-                reason=_("Unable to import the sushy library"))
-
     def get_properties(self):
         """Return the properties of the interface.
 
@@ -71,6 +62,7 @@ class RedfishFirmware(base.FirmwareInterface):
         """
         redfish_utils.parse_driver_info(task.node)
 
+    @METRICS.timer('RedfishFirmware.cache_firmware_components')
     def cache_firmware_components(self, task):
         """Store or update Firmware Components on the given node.
 
@@ -86,29 +78,40 @@ class RedfishFirmware(base.FirmwareInterface):
         node_id = task.node.id
         settings = []
         # NOTE(iurygregory): currently we will only retrieve BIOS and BMC
-        # firmware information trough the redfish system and manager.
+        # firmware information through the redfish system and manager.
 
         system = redfish_utils.get_system(task.node)
 
-        bios_fw = {'component': 'bios',
-                   'current_version': system.bios_version}
-        settings.append(bios_fw)
+        if system.bios_version:
+            bios_fw = {'component': redfish_utils.BIOS,
+                       'current_version': system.bios_version}
+            settings.append(bios_fw)
+        else:
+            LOG.debug('Could not retrieve BiosVersion in node %(node_uuid)s '
+                      'system %(system)s', {'node_uuid': task.node.uuid,
+                                            'system': system.identity})
 
         # NOTE(iurygregory): normally we only relay on the System to
         # perform actions, but to retrieve the BMC Firmware we need to
         # access the Manager.
         try:
             manager = redfish_utils.get_manager(task.node, system)
-            bmc_fw = {'component': 'bmc',
-                      'current_version': manager.firmware_version}
-            settings.append(bmc_fw)
+            if manager.firmware_version:
+                bmc_fw = {'component': redfish_utils.BMC,
+                          'current_version': manager.firmware_version}
+                settings.append(bmc_fw)
+            else:
+                LOG.debug('Could not retrieve FirmwareVersion in node '
+                          '%(node_uuid)s manager %(manager)s',
+                          {'node_uuid': task.node.uuid,
+                           'manager': manager.identity})
         except exception.RedfishError:
             LOG.warning('No manager available to retrieve Firmware '
                         'from the bmc of node %s', task.node.uuid)
 
         if not settings:
-            error_msg = (_('Cannot retrieve firmware for node %s.')
-                         % task.node.uuid)
+            error_msg = (_('Cannot retrieve firmware for node %s: no '
+                           'supported components') % task.node.uuid)
             LOG.error(error_msg)
             raise exception.UnsupportedDriverExtension(error_msg)
 
@@ -157,19 +160,17 @@ class RedfishFirmware(base.FirmwareInterface):
         :returns: states.CLEANWAIT if Firmware update with the settings is in
             progress asynchronously of None if it is complete.
         """
+        firmware_utils.validate_firmware_interface_update_args(settings)
         node = task.node
-
         update_service = redfish_utils.get_update_service(node)
 
         LOG.debug('Updating Firmware on node %(node_uuid)s with settings '
                   '%(settings)s',
                   {'node_uuid': node.uuid, 'settings': settings})
-
         self._execute_firmware_update(node, update_service, settings)
 
         fw_upd = settings[0]
         wait_interval = fw_upd.get('wait')
-
         deploy_utils.set_async_step_flags(
             node,
             reboot=True,
@@ -196,8 +197,13 @@ class RedfishFirmware(base.FirmwareInterface):
                   '%(node_uuid)s',
                   {'url': fw_upd['url'], 'component': fw_upd['component'],
                    'node_uuid': node.uuid})
-
-        task_monitor = update_service.simple_update(component_url)
+        try:
+            task_monitor = update_service.simple_update(component_url)
+        except sushy.exceptions.MissingAttributeError as e:
+            LOG.error('The attribute #UpdateService.SimpleUpdate is missing '
+                      'on node %(node)s. Error: %(error)s',
+                      {'node': node.uuid, 'error': e.message})
+            raise exception.RedfishError(error=e)
 
         fw_upd['task_monitor'] = task_monitor.task_monitor_uri
         node.set_driver_internal_info('redfish_fw_updates', settings)
@@ -323,8 +329,7 @@ class RedfishFirmware(base.FirmwareInterface):
             LOG.warning('Unable to communicate with firmware update service '
                         'on node %(node)s. Will try again on the next poll. '
                         'Error: %(error)s',
-                        {'node': node.uuid,
-                         'error': e})
+                        {'node': node.uuid, 'error': e})
             return
 
         wait_start_time = current_update.get('wait_start_time')
@@ -450,3 +455,4 @@ class RedfishFirmware(base.FirmwareInterface):
 
         except exception.IronicException:
             firmware_utils.cleanup(node)
+            raise
