@@ -25,6 +25,7 @@ from ironic.common.i18n import _
 from ironic.common import image_service
 from ironic.common import swift
 from ironic.conf import CONF
+from ironic.drivers.modules.redfish import utils as redfish_utils
 
 LOG = log.getLogger(__name__)
 
@@ -65,9 +66,10 @@ _UPDATE_FIRMWARE_SCHEMA = {
 }
 
 _FIRMWARE_INTERFACE_UPDATE_SCHEMA = {
-    "$schema": "http://json-schema.org/schema#",
+    "$schema": "http://json-schema.org/draft-04/schema#",
     "title": "update_firmware clean step schema",
     "type": "array",
+    "minItems": 1,
     # list of firmware update images
     "items": {
         "type": "object",
@@ -76,7 +78,7 @@ _FIRMWARE_INTERFACE_UPDATE_SCHEMA = {
             "component": {
                 "description": "name of the firmware component to be updated",
                 "type": "string",
-                "minLenght": 1
+                "enum": redfish_utils.FIRMWARE_COMPONENTS
             },
             "url": {
                 "description": "URL for firmware file",
@@ -302,14 +304,13 @@ def cleanup(node):
         LOG.debug('For node %(node)s cleaning up files from Swift container '
                   '%(container)s.',
                   {'node': node.uuid, 'container': container})
-        _, objects = swift_api.connection.get_container(container)
+        objects = swift_api.connection.list_objects(container)
         for o in objects:
-            name = o.get('name')
-            if name and name.startswith(node.uuid):
+            if o.name and o.name.startswith(node.uuid):
                 try:
-                    swift_api.delete_object(container, name)
+                    swift_api.delete_object(container, o.name)
                 except exception.SwiftOperationError as error:
                     LOG.warning('For node %(node)s failed to clean up '
                                 '%(object)s. Error: %(error)s',
-                                {'node': node.uuid, 'object': name,
+                                {'node': node.uuid, 'object': o.name,
                                  'error': error})
