@@ -19,8 +19,8 @@ from urllib.parse import urlparse
 
 from ironic_lib import metrics_utils
 from oslo_log import log
-from oslo_utils import importutils
 from oslo_utils import timeutils
+import sushy
 
 from ironic.common import boot_devices
 from ironic.common import boot_modes
@@ -37,60 +37,59 @@ from ironic.conf import CONF
 from ironic.drivers import base
 from ironic.drivers.modules import boot_mode_utils
 from ironic.drivers.modules import deploy_utils
+from ironic.drivers.modules.redfish import boot as redfish_boot
 from ironic.drivers.modules.redfish import firmware_utils
 from ironic.drivers.modules.redfish import utils as redfish_utils
 
 LOG = log.getLogger(__name__)
 METRICS = metrics_utils.get_metrics_logger(__name__)
 
-sushy = importutils.try_import('sushy')
-
 BOOT_MODE_CONFIG_INTERVAL = 15
 
-if sushy:
-    BOOT_DEVICE_MAP = {
-        sushy.BOOT_SOURCE_TARGET_PXE: boot_devices.PXE,
-        sushy.BOOT_SOURCE_TARGET_HDD: boot_devices.DISK,
-        sushy.BOOT_SOURCE_TARGET_CD: boot_devices.CDROM,
-        sushy.BOOT_SOURCE_TARGET_BIOS_SETUP: boot_devices.BIOS
-    }
+BOOT_DEVICE_MAP = {
+    sushy.BOOT_SOURCE_TARGET_PXE: boot_devices.PXE,
+    sushy.BOOT_SOURCE_TARGET_HDD: boot_devices.DISK,
+    sushy.BOOT_SOURCE_TARGET_CD: boot_devices.CDROM,
+    sushy.BOOT_SOURCE_TARGET_BIOS_SETUP: boot_devices.BIOS,
+    sushy.BOOT_SOURCE_TARGET_UEFI_HTTP: boot_devices.UEFIHTTP
+}
 
-    BOOT_DEVICE_MAP_REV = {v: k for k, v in BOOT_DEVICE_MAP.items()}
-    # Previously we used sushy constants in driver_internal_info. This mapping
-    # is provided for backward compatibility, taking into account that sushy
-    # constants will change from strings to enums.
-    BOOT_DEVICE_MAP_REV_COMPAT = dict(
-        BOOT_DEVICE_MAP_REV,
-        pxe=sushy.BOOT_SOURCE_TARGET_PXE,
-        hdd=sushy.BOOT_SOURCE_TARGET_HDD,
-        cd=sushy.BOOT_SOURCE_TARGET_CD,
-        **{'bios setup': sushy.BOOT_SOURCE_TARGET_BIOS_SETUP}
-    )
+BOOT_DEVICE_MAP_REV = {v: k for k, v in BOOT_DEVICE_MAP.items()}
+# Previously we used sushy constants in driver_internal_info. This mapping
+# is provided for backward compatibility, taking into account that sushy
+# constants will change from strings to enums.
+BOOT_DEVICE_MAP_REV_COMPAT = dict(
+    BOOT_DEVICE_MAP_REV,
+    pxe=sushy.BOOT_SOURCE_TARGET_PXE,
+    hdd=sushy.BOOT_SOURCE_TARGET_HDD,
+    cd=sushy.BOOT_SOURCE_TARGET_CD,
+    **{'bios setup': sushy.BOOT_SOURCE_TARGET_BIOS_SETUP}
+)
 
-    BOOT_MODE_MAP = {
-        sushy.BOOT_SOURCE_MODE_UEFI: boot_modes.UEFI,
-        sushy.BOOT_SOURCE_MODE_BIOS: boot_modes.LEGACY_BIOS
-    }
+BOOT_MODE_MAP = {
+    sushy.BOOT_SOURCE_MODE_UEFI: boot_modes.UEFI,
+    sushy.BOOT_SOURCE_MODE_BIOS: boot_modes.LEGACY_BIOS
+}
 
-    BOOT_MODE_MAP_REV = {v: k for k, v in BOOT_MODE_MAP.items()}
+BOOT_MODE_MAP_REV = {v: k for k, v in BOOT_MODE_MAP.items()}
 
-    BOOT_DEVICE_PERSISTENT_MAP = {
-        sushy.BOOT_SOURCE_ENABLED_CONTINUOUS: True,
-        sushy.BOOT_SOURCE_ENABLED_ONCE: False
-    }
+BOOT_DEVICE_PERSISTENT_MAP = {
+    sushy.BOOT_SOURCE_ENABLED_CONTINUOUS: True,
+    sushy.BOOT_SOURCE_ENABLED_ONCE: False
+}
 
-    BOOT_DEVICE_PERSISTENT_MAP_REV = {v: k for k, v in
-                                      BOOT_DEVICE_PERSISTENT_MAP.items()}
+BOOT_DEVICE_PERSISTENT_MAP_REV = {v: k for k, v in
+                                  BOOT_DEVICE_PERSISTENT_MAP.items()}
 
-    INDICATOR_MAP = {
-        sushy.INDICATOR_LED_LIT: indicator_states.ON,
-        sushy.INDICATOR_LED_OFF: indicator_states.OFF,
-        sushy.INDICATOR_LED_BLINKING: indicator_states.BLINKING,
-        sushy.INDICATOR_LED_UNKNOWN: indicator_states.UNKNOWN
-    }
+INDICATOR_MAP = {
+    sushy.INDICATOR_LED_LIT: indicator_states.ON,
+    sushy.INDICATOR_LED_OFF: indicator_states.OFF,
+    sushy.INDICATOR_LED_BLINKING: indicator_states.BLINKING,
+    sushy.INDICATOR_LED_UNKNOWN: indicator_states.UNKNOWN
+}
 
-    INDICATOR_MAP_REV = {
-        v: k for k, v in INDICATOR_MAP.items()}
+INDICATOR_MAP_REV = {
+    v: k for k, v in INDICATOR_MAP.items()}
 
 
 _FIRMWARE_UPDATE_ARGS = {
@@ -101,7 +100,8 @@ _FIRMWARE_UPDATE_ARGS = {
     }}
 
 
-def _set_boot_device(task, system, device, persistent=False):
+def _set_boot_device(task, system, device, persistent=False,
+                     http_boot_url=None):
     """An internal routine to set the boot device.
 
     :param task: a task from TaskManager.
@@ -110,6 +110,8 @@ def _set_boot_device(task, system, device, persistent=False):
     :param persistent: Boolean value. True if the boot device will
                        persist to all future boots, False if not.
                        Default: False.
+    :param http_boot_url: A string value to be sent to the sushy library,
+                          which is sent to the BMC as the url to boot from.
     :raises: SushyError on an error from the Sushy library
     """
 
@@ -133,7 +135,10 @@ def _set_boot_device(task, system, device, persistent=False):
         enabled = (desired_enabled
                    if desired_enabled != current_enabled else None)
     try:
-        system.set_system_boot_options(device, enabled=enabled)
+        # NOTE(TheJulia): In sushy, it is uri, due to the convention used
+        # in the standard. URL is used internally in ironic.
+        system.set_system_boot_options(device, enabled=enabled,
+                                       http_boot_uri=http_boot_url)
     except sushy.exceptions.SushyError as e:
         if enabled == sushy.BOOT_SOURCE_ENABLED_CONTINUOUS:
             # NOTE(dtantsur): continuous boot device settings have been
@@ -146,7 +151,8 @@ def _set_boot_device(task, system, device, persistent=False):
                       'falling back to one-time boot settings',
                       {'error': e, 'node': task.node.uuid})
             system.set_system_boot_options(
-                device, enabled=sushy.BOOT_SOURCE_ENABLED_ONCE)
+                device, enabled=sushy.BOOT_SOURCE_ENABLED_ONCE,
+                http_boot_uri=http_boot_url)
             LOG.warning('Could not set persistent boot device to '
                         '%(dev)s for node %(node)s, using one-time '
                         'boot device instead',
@@ -161,18 +167,6 @@ def _set_boot_device(task, system, device, persistent=False):
 
 class RedfishManagement(base.ManagementInterface):
 
-    def __init__(self):
-        """Initialize the Redfish management interface.
-
-        :raises: DriverLoadError if the driver can't be loaded due to
-            missing dependencies
-        """
-        super(RedfishManagement, self).__init__()
-        if not sushy:
-            raise exception.DriverLoadError(
-                driver='redfish',
-                reason=_('Unable to import the sushy library'))
-
     def get_properties(self):
         """Return the properties of the interface.
 
@@ -254,6 +248,8 @@ class RedfishManagement(base.ManagementInterface):
         """
         utils.pop_node_nested_field(
             task.node, 'driver_internal_info', 'redfish_boot_device')
+        http_boot_url = utils.pop_node_nested_field(
+            task.node, 'driver_internal_info', 'redfish_uefi_http_url')
         task.node.save()
 
         system = redfish_utils.get_system(task.node)
@@ -261,7 +257,7 @@ class RedfishManagement(base.ManagementInterface):
         try:
             _set_boot_device(
                 task, system, BOOT_DEVICE_MAP_REV[device],
-                persistent=persistent)
+                persistent=persistent, http_boot_url=http_boot_url)
         except sushy.exceptions.SushyError as e:
             error_msg = (_('Redfish set boot device failed for node '
                            '%(node)s. Error: %(error)s') %
@@ -516,15 +512,18 @@ class RedfishManagement(base.ManagementInterface):
         """
         sensors = {}
 
-        for storage in system.simple_storage.get_members():
-            for drive in storage.devices:
-                sensor = cls._sensor2dict(
-                    drive, 'name', 'model', 'capacity_bytes')
-                sensor.update(
-                    cls._sensor2dict(drive.status, 'state', 'health'))
-                unique_name = '%s:%s@%s' % (
-                    drive.name, storage.identity, system.identity)
-                sensors[unique_name] = sensor
+        if storages := system.storage or system.simple_storage:
+            for storage in storages.get_members():
+                drives = storage.drives if hasattr(
+                    storage, 'drives') else storage.devices
+                for drive in drives:
+                    sensor = cls._sensor2dict(
+                        drive, 'name', 'model', 'capacity_bytes')
+                    sensor.update(
+                        cls._sensor2dict(drive.status, 'state', 'health'))
+                    unique_name = '%s:%s@%s' % (
+                        drive.name, storage.identity, system.identity)
+                    sensors[unique_name] = sensor
 
         return sensors
 
@@ -685,11 +684,14 @@ class RedfishManagement(base.ManagementInterface):
 
         try:
             if (component in (None, components.DISK)
-                    and system.simple_storage
-                    and system.simple_storage.drives):
+                    and system.storage):
                 indicators[components.DISK] = {
-                    drive.uuid: properties
-                    for drive in system.simple_storage.drives
+                    # NOTE(vanou) There is no uuid property in Drive resource.
+                    # There is no guarantee Id property of Drive is unique
+                    # across all drives attached to server.
+                    ':'.join([storage.identity, drive.identity]): properties
+                    for storage in system.storage.get_members()
+                    for drive in storage.drives
                     if drive.indicator_led
                 }
 
@@ -731,13 +733,14 @@ class RedfishManagement(base.ManagementInterface):
                         return
 
             elif (component == components.DISK
-                  and system.simple_storage
-                  and system.simple_storage.drives):
-                for drive in system.simple_storage.drives:
-                    if drive.uuid == indicator:
-                        drive.set_indicator_led(
-                            INDICATOR_MAP_REV[state])
-                        return
+                  and system.storage and len(indicator.split(':')) == 2):
+                for storage in system.storage.get_members():
+                    if storage.identity == indicator.split(':')[0]:
+                        for drive in storage.drives:
+                            if drive.identity == indicator.split(':')[1]:
+                                drive.set_indicator_led(
+                                    INDICATOR_MAP_REV[state])
+                                return
 
         except sushy.exceptions.SushyError as e:
             error_msg = (_('Redfish set %(component)s indicator %(indicator)s '
@@ -783,11 +786,12 @@ class RedfishManagement(base.ManagementInterface):
                         return INDICATOR_MAP[chassis.indicator_led]
 
             if (component == components.DISK
-                    and system.simple_storage
-                    and system.simple_storage.drives):
-                for drive in system.simple_storage.drives:
-                    if drive.uuid == indicator:
-                        return INDICATOR_MAP[drive.indicator_led]
+                    and system.storage and len(indicator.split(':')) == 2):
+                for storage in system.storage.get_members():
+                    if storage.identity == indicator.split(':')[0]:
+                        for drive in storage.drives:
+                            if drive.identity == indicator.split(':')[1]:
+                                return INDICATOR_MAP[drive.indicator_led]
 
         except sushy.exceptions.SushyError as e:
             error_msg = (_('Redfish get %(component)s indicator %(indicator)s '
@@ -1331,3 +1335,27 @@ class RedfishManagement(base.ManagementInterface):
                    % {'node': task.node.uuid, 'exc': exc})
             LOG.error(msg)
             raise exception.RedfishError(error=msg)
+
+    @task_manager.require_exclusive_lock
+    def attach_virtual_media(self, task, device_type, image_url):
+        """Attach a virtual media device to the node.
+
+            :param task: A task from TaskManager.
+            :param device_type: A device type from
+                :data:`ironic.common.boot_devices.VMEDIA_DEVICES`.
+            :param image_url: URL of the image to attach, HTTP or HTTPS.
+
+        """
+        redfish_boot.insert_vmedia(task, image_url, device_type)
+
+    @task_manager.require_exclusive_lock
+    def detach_virtual_media(self, task, device_type=None):
+        """Detach some or all virtual media devices from the node.
+
+            :param task: A task from TaskManager.
+            :param device_type: A device type from
+                :data:`ironic.common.boot_devices.VMEDIA_DEVICES`.
+                If not provided, all devices are detached.
+
+        """
+        redfish_boot.eject_vmedia(task, device_type)
