@@ -18,8 +18,8 @@ import math
 
 from ironic_lib import metrics_utils
 from oslo_log import log
-from oslo_utils import importutils
 from oslo_utils import units
+import sushy
 
 from ironic.common import exception
 from ironic.common.i18n import _
@@ -84,13 +84,10 @@ RAID_LEVELS = {
     }
 }
 
-sushy = importutils.try_import('sushy')
-
-if sushy:
-    PROTOCOL_MAP = {
-        sushy.PROTOCOL_TYPE_SAS: raid.SAS,
-        sushy.PROTOCOL_TYPE_SATA: raid.SATA
-    }
+PROTOCOL_MAP = {
+    sushy.PROTOCOL_TYPE_SAS: raid.SAS,
+    sushy.PROTOCOL_TYPE_SATA: raid.SATA
+}
 
 
 def convert_drive_units(logical_disks, node):
@@ -620,6 +617,8 @@ def _construct_volume_payload(
             "Drives": [{"@odata.id": _drive_path(storage, d)} for d in
                        physical_disks]
         }
+    if disk_name:
+        payload['Name'] = disk_name
     LOG.debug('Payload for RAID logical disk creation on node %(node_uuid)s: '
               '%(payload)r', {'node_uuid': node.uuid, 'payload': payload})
     return payload
@@ -713,13 +712,6 @@ def update_raid_config(node):
 
 class RedfishRAID(base.RAIDInterface):
 
-    def __init__(self):
-        super(RedfishRAID, self).__init__()
-        if sushy is None:
-            raise exception.DriverLoadError(
-                driver='redfish',
-                reason=_("Unable to import the sushy library"))
-
     def get_properties(self):
         """Return the properties of the interface.
 
@@ -1098,7 +1090,7 @@ class RedfishRAID(base.RAIDInterface):
                     physical_disks=logical_disk['physical_disks'],
                     raid_level=logical_disk['raid_level'],
                     size_bytes=logical_disk['size_bytes'],
-                    disk_name=logical_disk.get('name'),
+                    disk_name=logical_disk.get('volume_name'),
                     span_length=logical_disk.get('span_length'),
                     span_depth=logical_disk.get('span_depth'),
                     error_handler=self.volume_create_error_handler)
