@@ -21,9 +21,9 @@ from urllib import parse as urlparse
 
 from oslo_log import log
 from oslo_utils import excutils
-from oslo_utils import importutils
 from oslo_utils import strutils
 import rfc3986
+import sushy
 import tenacity
 
 from ironic.common import exception
@@ -31,8 +31,6 @@ from ironic.common.i18n import _
 from ironic.common import utils
 from ironic.conf import CONF
 
-sushy = importutils.try_import('sushy')
-
 LOG = log.getLogger(__name__)
 
 REQUIRED_PROPERTIES = {
@@ -200,13 +198,12 @@ def parse_driver_info(node):
 
 class SessionCache(object):
     """Cache of HTTP sessions credentials"""
-    AUTH_CLASSES = {}
-    if sushy:
-        AUTH_CLASSES.update(
-            basic=sushy.auth.BasicAuth,
-            session=sushy.auth.SessionAuth,
-            auto=sushy.auth.SessionOrBasicAuth
-        )
+
+    AUTH_CLASSES = dict(
+        basic=sushy.auth.BasicAuth,
+        session=sushy.auth.SessionAuth,
+        auto=sushy.auth.SessionOrBasicAuth
+    )
 
     _sessions = collections.OrderedDict()
 
@@ -215,13 +212,9 @@ class SessionCache(object):
         # include it in the session key.
         # NOTE(TheJulia): Multiplying the address by 4, to ensure
         # we meet a minimum of 16 bytes for salt.
-        # NOTE(frickler): password may be None, make sure we have a str
-        password = driver_info.get('password')
-        if not password:
-            password = ''
         pw_hash = hashlib.pbkdf2_hmac(
             'sha512',
-            password.encode('utf-8'),
+            driver_info.get('password').encode('utf-8'),
             str(driver_info.get('address') * 4).encode('utf-8'), 40)
         self._driver_info = driver_info
         # Assemble the session key and append the hashed password to it,
