@@ -107,7 +107,7 @@ class VolumeTarget(base.IronicObject,
     # @object_base.remotable_classmethod
     @classmethod
     def list(cls, context, limit=None, marker=None,
-             sort_key=None, sort_dir=None):
+             sort_key=None, sort_dir=None, project=None):
         """Return a list of VolumeTarget objects.
 
         :param context: security context
@@ -115,13 +115,16 @@ class VolumeTarget(base.IronicObject,
         :param marker: pagination marker for large data sets
         :param sort_key: column to sort results by
         :param sort_dir: direction to sort. "asc" or "desc".
+        :param project: The associated node project to search with.
+        :returns: a list of :class:`VolumeConnector` objects
         :returns: a list of :class:`VolumeTarget` objects
         :raises: InvalidParameterValue if sort_key does not exist
         """
         db_targets = cls.dbapi.get_volume_target_list(limit=limit,
                                                       marker=marker,
                                                       sort_key=sort_key,
-                                                      sort_dir=sort_dir)
+                                                      sort_dir=sort_dir,
+                                                      project=project)
         return cls._from_db_object_list(context, db_targets)
 
     # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
@@ -130,7 +133,7 @@ class VolumeTarget(base.IronicObject,
     # @object_base.remotable_classmethod
     @classmethod
     def list_by_node_id(cls, context, node_id, limit=None, marker=None,
-                        sort_key=None, sort_dir=None):
+                        sort_key=None, sort_dir=None, project=None):
         """Return a list of VolumeTarget objects related to a given node ID.
 
         :param context: security context
@@ -139,6 +142,8 @@ class VolumeTarget(base.IronicObject,
         :param marker: pagination marker for large data sets
         :param sort_key: column to sort results by
         :param sort_dir: direction to sort. "asc" or "desc".
+        :param project: The associated node project to search with.
+        :returns: a list of :class:`VolumeConnector` objects
         :returns: a list of :class:`VolumeTarget` objects
         :raises: InvalidParameterValue if sort_key does not exist
         """
@@ -147,7 +152,8 @@ class VolumeTarget(base.IronicObject,
             limit=limit,
             marker=marker,
             sort_key=sort_key,
-            sort_dir=sort_dir)
+            sort_dir=sort_dir,
+            project=project)
         return cls._from_db_object_list(context, db_targets)
 
     # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
@@ -156,7 +162,7 @@ class VolumeTarget(base.IronicObject,
     # @object_base.remotable_classmethod
     @classmethod
     def list_by_volume_id(cls, context, volume_id, limit=None, marker=None,
-                          sort_key=None, sort_dir=None):
+                          sort_key=None, sort_dir=None, project=None):
         """Return a list of VolumeTarget objects related to a given volume ID.
 
         :param context: security context
@@ -174,7 +180,8 @@ class VolumeTarget(base.IronicObject,
             limit=limit,
             marker=marker,
             sort_key=sort_key,
-            sort_dir=sort_dir)
+            sort_dir=sort_dir,
+            project=project)
         return cls._from_db_object_list(context, db_targets)
 
     # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
