@@ -15,8 +15,8 @@ Tests for the API /conductors/ methods.
 
 import datetime
 from http import client as http_client
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
@@ -85,6 +85,19 @@ class TestListConductors(test_api_base.BaseApiTest):
         self.assertEqual(data['hostname'], 'rocky.rocks')
         self.assertTrue(data['alive'])
 
+    def test_get_one_with_port_and_v6(self):
+        obj_utils.create_test_conductor(self.context, hostname='[::1]:8090')
+        data = self.get_json(
+            '/conductors/[::1]:8090',
+            headers={api_base.Version.string: str(api_v1.max_version())})
+        self.assertIn('hostname', data)
+        self.assertIn('drivers', data)
+        self.assertIn('conductor_group', data)
+        self.assertIn('alive', data)
+        self.assertIn('drivers', data)
+        self.assertEqual(data['hostname'], '[::1]:8090')
+        self.assertTrue(data['alive'])
+
     @mock.patch.object(timeutils, 'utcnow', autospec=True)
     def test_get_one_conductor_offline(self, mock_utcnow):
         self.config(heartbeat_timeout=10, group='conductor')
@@ -188,7 +201,9 @@ class TestListConductors(test_api_base.BaseApiTest):
         self.assertEqual(3, len(data['conductors']))
 
         next_marker = data['conductors'][-1]['hostname']
-        self.assertIn(next_marker, data['next'])
+        self.assertIn('/conductors', data['next'])
+        self.assertIn('limit=3', data['next'])
+        self.assertIn(f'marker={next_marker}', data['next'])
 
     def test_collection_links_default_limit(self):
         cfg.CONF.set_override('max_limit', 3, 'api')
@@ -204,7 +219,8 @@ class TestListConductors(test_api_base.BaseApiTest):
         self.assertEqual(3, len(data['conductors']))
 
         next_marker = data['conductors'][-1]['hostname']
-        self.assertIn(next_marker, data['next'])
+        self.assertIn('/conductors', data['next'])
+        self.assertIn(f'marker={next_marker}', data['next'])
 
     def test_collection_links_custom_fields(self):
         cfg.CONF.set_override('max_limit', 3, 'api')
@@ -221,8 +237,9 @@ class TestListConductors(test_api_base.BaseApiTest):
         self.assertEqual(3, len(data['conductors']))
 
         next_marker = data['conductors'][-1]['hostname']
-        self.assertIn(next_marker, data['next'])
-        self.assertIn('fields', data['next'])
+        self.assertIn('/conductors', data['next'])
+        self.assertIn(f'marker={next_marker}', data['next'])
+        self.assertIn(f'fields={fields}', data['next'])
 
     def test_sort_key(self):
         conductors = []
