@@ -77,12 +77,14 @@ class TestACLBase(base.BaseApiTest):
     def _fake_process_request(self, request, auth_token_request):
         pass
 
-    def _test_request(self, path, params=None, headers=None, method='get',
+    def _test_request(self, path, params=None, headers=None, method='get',  # noqa: C901, E501
                       body=None, assert_status=None,
                       assert_dict_contains=None,
                       assert_list_length=None,
                       deprecated=None,
-                      self_manage_nodes=True):
+                      self_manage_nodes=True,
+                      enable_service_project=False,
+                      service_project='service'):
         path = path.format(**self.format_data)
         self.mock_auth.side_effect = self._fake_process_request
 
@@ -92,6 +94,13 @@ class TestACLBase(base.BaseApiTest):
                 'project_admin_can_manage_own_nodes',
                 False,
                 'api')
+        if enable_service_project:
+            cfg.CONF.set_override('rbac_service_role_elevated_access', True)
+        if service_project != 'service':
+            # Enable us to sort of gracefully test a name variation
+            # with existing ddt test modeling.
+            cfg.CONF.set_override('rbac_service_project_name',
+                                  service_project)
 
         # always request the latest api version
         version = api_versions.max_version_string()
@@ -156,7 +165,7 @@ class TestACLBase(base.BaseApiTest):
         #       Example: PATCH /v1/nodes/<uuid> as a reader.
         # 404 - Trying to access something where we don't have permissions
         #       in a project scope. This is particularly true where implied
-        #       permissions or assocation exists. Ports are attempted to be
+        #       permissions or association exists. Ports are attempted to be
         #       accessed when the underlying node is inaccessible as owner
         #       nor node matches.
         #       Example: GET /v1/portgroups or /v1/nodes/<uuid>/ports
@@ -189,7 +198,7 @@ class TestACLBase(base.BaseApiTest):
                     # json ends up being null in json or None.
                     self.assertIsNone(response.json[k])
                 elif str(v) == "{}":
-                    # Special match for signifying a dictonary.
+                    # Special match for signifying a dictionary.
                     self.assertEqual({}, response.json[k])
                 elif isinstance(v, dict):
                     # The value from the YAML can be a dictionary,
@@ -338,7 +347,7 @@ class TestRBACScoped(TestRBACModelBeforeScopes):
         # while we also enable the new ones in another test class with
         # the appropriate scope friendly chagnges. In other words, two
         # test changes will be needed for each which should also reduce
-        # risk of accidential policy changes. It may just be Julia being
+        # risk of accidental policy changes. It may just be Julia being
         # super risk-adverse, just let her roll with it and we will delete
         # this class later.
         # NOTE(TheJulia): This test class runs with test_rbac_legacy.yaml!
