@@ -12,8 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-
 from ironic.common import states
 from ironic.tests import base
 
@@ -31,7 +29,7 @@ class StatesTest(base.TestCase):
         for key, value in states.__dict__.items():
             # Assumption: A state variable name is all UPPERCASE and contents
             # are a string.
-            if key.upper() == key and isinstance(value, six.string_types):
+            if key.upper() == key and isinstance(value, str):
                 self.assertLessEqual(
                     len(value), 15,
                     "Value for state: {} is greater than 15 characters".format(
