@@ -19,6 +19,8 @@ from ironic.common import exception
 from ironic.common import states
 from ironic.conductor import steps as conductor_steps
 from ironic.conductor import task_manager
+from ironic.conductor import utils as conductor_utils
+from ironic.conductor import verify as verify_steps
 from ironic import objects
 from ironic.tests.unit.db import base as db_base
 from ironic.tests.unit.db import utils as db_utils
@@ -579,15 +581,27 @@ class NodeCleaningStepsTestCase(db_base.DbTestCase):
         self.deploy_erase = {
             'step': 'erase_disks', 'priority': 20, 'interface': 'deploy',
             'abortable': True}
+        self.vendor_action = {
+            'abortable': False, 'argsinfo': None, 'interface': 'vendor',
+            'priority': 1, 'requires_ramdisk': True,
+            'step': 'log_passthrough'}
+        self.firmware_step = {
+            'abortable': False, 'argsinfo': {}, 'interface': 'firmware',
+            'priority': 0, 'requires_ramdisk': True,
+            'step': 'update'
+        }
+
         # Automated cleaning should be executed in this order
         self.clean_steps = [self.deploy_erase, self.power_update,
-                            self.deploy_update]
+                            self.deploy_update, self.vendor_action]
         # Manual clean step
         self.deploy_raid = {
             'step': 'build_raid', 'priority': 0, 'interface': 'deploy',
             'argsinfo': {'arg1': {'description': 'desc1', 'required': True},
                          'arg2': {'description': 'desc2'}}}
 
+    @mock.patch('ironic.drivers.modules.fake.FakeFirmware.get_clean_steps',
+                lambda self, taks: [])
     @mock.patch('ironic.drivers.modules.fake.FakeBIOS.get_clean_steps',
                 lambda self, task: [])
     @mock.patch('ironic.drivers.modules.fake.FakeDeploy.get_clean_steps',
@@ -612,6 +626,10 @@ class NodeCleaningStepsTestCase(db_base.DbTestCase):
 
         self.assertEqual(self.clean_steps, steps)
 
+    @mock.patch('ironic.drivers.modules.fake.FakeFirmware.get_clean_steps',
+                lambda self, task: [])
+    @mock.patch('ironic.drivers.modules.fake.FakeVendorB.get_clean_steps',
+                lambda self, task: [])
     @mock.patch('ironic.drivers.modules.fake.FakeBIOS.get_clean_steps',
                 lambda self, task: [])
     @mock.patch('ironic.drivers.modules.fake.FakeDeploy.get_clean_steps',
@@ -659,6 +677,8 @@ class NodeCleaningStepsTestCase(db_base.DbTestCase):
 
         self.assertEqual(self.clean_steps, steps)
 
+    @mock.patch('ironic.drivers.modules.fake.FakeVendorB.get_clean_steps',
+                lambda self, task: [])
     @mock.patch('ironic.drivers.modules.fake.FakeDeploy.get_clean_steps',
                 autospec=True)
     @mock.patch('ironic.drivers.modules.fake.FakePower.get_clean_steps',
@@ -764,7 +784,13 @@ class NodeCleaningStepsTestCase(db_base.DbTestCase):
                                     {'interface': 'power', 'priority': 10,
                                      'step': 'update_firmware'},
                                     {'interface': 'deploy', 'priority': 10,
-                                     'step': 'update_firmware'}]
+                                     'step': 'update_firmware'},
+                                    {'abortable': False,
+                                     'argsinfo': None,
+                                     'interface': 'vendor',
+                                     'priority': 1,
+                                     'requires_ramdisk': True,
+                                     'step': 'log_passthrough'}]
 
         self.assertEqual(expected_step_priorities, steps)
 
@@ -779,7 +805,8 @@ class NodeCleaningStepsTestCase(db_base.DbTestCase):
         cfg.CONF.set_override('clean_step_priority_override',
                               ["deploy.erase_disks:0",
                                "power.update_firmware:0",
-                               "deploy.update_firmware:0", ],
+                               "deploy.update_firmware:0",
+                               "vendor.log_passthrough:0", ],
                               'conductor')
 
         node = obj_utils.create_test_node(
@@ -970,6 +997,19 @@ class NodeCleaningStepsTestCase(db_base.DbTestCase):
                      'priority': 20, 'abortable': True}]
         self.assertEqual(expected, result)
 
+    @mock.patch.object(conductor_steps, '_validate_user_step',
+                       autospec=True)
+    def test__validate_user_clean_steps_reserved_options(self, mock_steps):
+        node = obj_utils.create_test_node(self.context)
+        user_steps = [{'step': 'magic', 'execute_on_child_nodes': True},
+                      {'step': 'power_on', 'interface': 'power'},
+                      {'step': 'power_off', 'interface': 'power'},
+                      {'step': 'reboot', 'interface': 'power'}]
+        with task_manager.acquire(self.context, node.uuid) as task:
+            conductor_steps._validate_user_clean_steps(
+                task, user_steps, disable_ramdisk=True)
+            mock_steps.assert_not_called()
+
 
 @mock.patch.object(conductor_steps, '_get_deployment_templates',
                    autospec=True)
@@ -1028,8 +1068,8 @@ class GetValidatedStepsFromTemplatesTestCase(db_base.DbTestCase):
                                      mock_templates):
         mock_templates.return_value = [self.template]
         mock_validate.side_effect = exception.InstanceDeployFailure('foo')
-        with task_manager.acquire(
-                self.context, self.node.uuid, shared=False) as task:
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
             self.assertRaises(
                 exception.InstanceDeployFailure,
                 conductor_steps._get_validated_steps_from_templates, task)
@@ -1138,3 +1178,317 @@ class ValidateUserDeployStepsTestCase(db_base.DbTestCase):
             result = conductor_steps._get_validated_user_deploy_steps(task)
             self.assertEqual([], result)
             mock_validated.assert_not_called()
+
+
+class NodeVerifyStepsTestCase(db_base.DbTestCase):
+    def setUp(self):
+        super(NodeVerifyStepsTestCase, self).setUp()
+
+        self.management_reset_idrac = {
+            'step': 'reset_idrac', 'priority': 0,
+            'interface': 'management'}
+        self.management_clear_job_queue = {
+            'step': 'clear_job_queue', 'priority': 10,
+            'interface': 'management'}
+        self.verify_steps = [self.management_clear_job_queue,
+                             self.management_reset_idrac]
+        self.verify_steps_only_enabled = [self.management_clear_job_queue]
+
+    @mock.patch('ironic.drivers.modules.fake.FakeManagement.get_verify_steps',
+                autospec=True)
+    def test__get_verify_steps_priority_override_ok(self,
+                                                    mock_verify_steps):
+        # Test verify_step_priority_override
+        cfg.CONF.set_override('verify_step_priority_override',
+                              ["management.clear_job_queue:9"],
+                              'conductor')
+
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.ENROLL,
+            target_provision_state=states.MANAGEABLE)
+
+        mock_verify_steps.return_value = [self.management_clear_job_queue]
+
+        with task_manager.acquire(
+                self.context, node.uuid, shared=True) as task:
+            steps = conductor_steps._get_verify_steps(task, enabled=True)
+
+        expected_step_priorities = [{'interface': 'management', 'priority': 9,
+                                     'step': 'clear_job_queue'}]
+
+        self.assertEqual(expected_step_priorities, steps)
+
+    @mock.patch('ironic.drivers.modules.fake.FakeManagement.get_verify_steps',
+                autospec=True)
+    def test__get_verify_steps_priority_override_fail(self,
+                                                      mock_verify_steps):
+        # Test verify_step_priority_override for failure
+        cfg.CONF.set_override('verify_step_priority_override',
+                              ["management.clear_job_queue:9"],
+                              'conductor')
+
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.ENROLL,
+            target_provision_state=states.MANAGEABLE)
+
+        mock_verify_steps.return_value = [self.management_clear_job_queue]
+
+        with task_manager.acquire(
+                self.context, node.uuid, shared=True) as task:
+            steps = conductor_steps._get_verify_steps(task, enabled=True)
+
+        expected_step_priorities = [{'interface': 'management', 'priority': 10,
+                                     'step': 'clear_job_queue'}]
+
+        self.assertNotEqual(expected_step_priorities, steps)
+
+    @mock.patch('ironic.drivers.modules.fake.FakeManagement.get_verify_steps',
+                autospec=True)
+    def test__get_verify_steps_priority_override_off(self,
+                                                     mock_verify_steps):
+        # Test disabling steps with verify_step_priority_override
+        cfg.CONF.set_override('verify_step_priority_override',
+                              ["management.clear_job_queue:0"],
+                              'conductor')
+
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.ENROLL,
+            target_provision_state=states.MANAGEABLE)
+
+        mock_verify_steps.return_value = [self.management_clear_job_queue]
+
+        with task_manager.acquire(
+                self.context, node.uuid, shared=True) as task:
+            steps = conductor_steps._get_verify_steps(task, enabled=True)
+
+        expected_step_priorities = []
+
+        self.assertEqual(expected_step_priorities, steps)
+
+    @mock.patch('ironic.drivers.modules.fake.FakeManagement.get_verify_steps',
+                autospec=True)
+    def test__get_verify_steps(self, mock_verify_steps):
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.ENROLL,
+            target_provision_state=states.MANAGEABLE)
+
+        mock_verify_steps.return_value = [self.management_clear_job_queue,
+                                          self.management_reset_idrac]
+
+        with task_manager.acquire(
+                self.context, node.uuid, shared=False) as task:
+            steps = conductor_steps._get_verify_steps(task, enabled=False)
+
+        self.assertEqual(self.verify_steps, steps)
+
+    @mock.patch('ironic.drivers.modules.fake.FakeManagement.get_verify_steps',
+                autospec=True)
+    def test__get_verify_steps_unsorted(self, mock_verify_steps):
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.ENROLL,
+            target_provision_state=states.MANAGEABLE)
+
+        mock_verify_steps.return_value = [self.management_clear_job_queue,
+                                          self.management_reset_idrac]
+
+        with task_manager.acquire(
+                self.context, node.uuid, shared=False) as task:
+            steps = conductor_steps._get_verify_steps(task, enabled=False,
+                                                      sort=False)
+
+        self.assertEqual(self.verify_steps, steps)
+
+    @mock.patch('ironic.drivers.modules.fake.FakeManagement.get_verify_steps',
+                autospec=True)
+    def test__get_verify_steps_only_enabled(self, mock_verify_steps):
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.ENROLL,
+            target_provision_state=states.MANAGEABLE)
+
+        mock_verify_steps.return_value = [self.management_clear_job_queue]
+
+        with task_manager.acquire(
+                self.context, node.uuid, shared=False) as task:
+            steps = conductor_steps._get_verify_steps(task, enabled=True)
+
+        self.assertEqual(self.verify_steps_only_enabled, steps)
+
+    @mock.patch('ironic.drivers.modules.fake.FakeManagement.'
+                'execute_verify_step',
+                autospec=True)
+    @mock.patch.object(conductor_steps, '_get_verify_steps', autospec=True)
+    def test_execute_verify_step(self, mock_steps, mock_execute):
+        mock_steps.return_value = self.verify_steps
+
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.VERIFYING,
+            target_provision_state=states.MANAGEABLE,
+            last_error=None,
+            clean_step=None)
+
+        with task_manager.acquire(
+                self.context, node.uuid, shared=False) as task:
+            verify_steps.do_node_verify(task)
+            node.refresh()
+            self.assertTrue(mock_execute.called)
+
+
+class ReservedStepsHandlerTestCase(db_base.DbTestCase):
+    def setUp(self):
+        super(ReservedStepsHandlerTestCase, self).setUp()
+
+    @mock.patch.object(conductor_utils, 'node_power_action',
+                       autospec=True)
+    def _test_reserved_step(self, step, mock_power_action):
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.CLEANING,
+            target_provision_state=states.MANAGEABLE,
+            last_error=None,
+            clean_step=None)
+        with task_manager.acquire(
+                self.context, node.uuid, shared=False) as task:
+            res = conductor_steps.use_reserved_step_handler(task, step)
+            self.assertTrue(res)
+
+    def test_reserved_step_power_on(self):
+        self._test_reserved_step({'step': 'power_on'})
+
+    def test_reserved_step_power_off(self):
+        self._test_reserved_step({'step': 'power_off'})
+
+    def test_reserved_step_power_reboot(self):
+        self._test_reserved_step({'step': 'reboot'})
+
+
+class ReservedStepHandlerByNameTestCase(db_base.DbTestCase):
+    def setUp(self):
+        super(ReservedStepHandlerByNameTestCase, self).setUp()
+
+    @mock.patch.object(conductor_steps, '_sleep_wrapper', autospec=True)
+    def _test_reserved_step(self, step, mock_sleep):
+        CONF.set_override('max_conductor_wait_step_seconds', 2,
+                          group='conductor')
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.CLEANING,
+            target_provision_state=states.MANAGEABLE,
+            last_error=None,
+            clean_step=None)
+        with task_manager.acquire(
+                self.context, node.uuid, shared=False) as task:
+            res = conductor_steps.use_reserved_step_handler(task, step)
+            self.assertTrue(res)
+            if step.get('step') == 'wait':
+                if 'args' in step:
+                    self.assertEqual(task.node.provision_state,
+                                     states.CLEANING)
+                    if step['args']['seconds'] == 3:
+                        mock_sleep.assert_called_once_with(2)
+                    else:
+                        mock_sleep.assert_called_once_with(
+                            step['args']['seconds'])
+                else:
+                    self.assertEqual(task.node.provision_state,
+                                     states.CLEANWAIT)
+                    mock_sleep.assert_not_called()
+
+    def test_reserved_step_wait(self):
+        self._test_reserved_step({'step': 'wait'})
+
+    def test_reserved_step_wait_time_to_long(self):
+        self._test_reserved_step({'step': 'wait', 'args': {'seconds': 3}})
+
+    def test_reserved_step_wait_time(self):
+        self._test_reserved_step({'step': 'wait', 'args': {'seconds': 1}})
+
+
+class NodeServiceStepsTestCase(db_base.DbTestCase):
+    def setUp(self):
+        super(NodeServiceStepsTestCase, self).setUp()
+
+        self.deploy_start = {
+            'step': 'deploy_start', 'priority': 50, 'interface': 'deploy'}
+        self.power_one = {
+            'step': 'power_one', 'priority': 40, 'interface': 'power'}
+        self.deploy_middle = {
+            'step': 'deploy_middle', 'priority': 40, 'interface': 'deploy'}
+        self.deploy_end = {
+            'step': 'deploy_end', 'priority': 20, 'interface': 'deploy'}
+        self.power_disable = {
+            'step': 'power_disable', 'priority': 0, 'interface': 'power'}
+        self.deploy_core = {
+            'step': 'deploy', 'priority': 100, 'interface': 'deploy'}
+        # enabled steps
+        self.service_steps = [self.deploy_start, self.power_one,
+                              self.deploy_middle, self.deploy_end]
+        # Deploy step with argsinfo.
+        self.deploy_raid = {
+            'step': 'build_raid', 'priority': 0, 'interface': 'deploy',
+            'argsinfo': {'arg1': {'description': 'desc1', 'required': True},
+                         'arg2': {'description': 'desc2'}}}
+        self.node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware')
+
+    @mock.patch('ironic.drivers.modules.fake.FakeDeploy.get_service_steps',
+                autospec=True)
+    @mock.patch('ironic.drivers.modules.fake.FakePower.get_service_steps',
+                autospec=True)
+    @mock.patch('ironic.drivers.modules.fake.FakeManagement.get_service_steps',
+                autospec=True)
+    def test__get_service_steps(self, mock_mgt_steps, mock_power_steps,
+                                mock_deploy_steps):
+        # Test getting deploy steps, with one driver returning None, two
+        # conflicting priorities, and asserting they are ordered properly.
+
+        mock_power_steps.return_value = [self.power_disable, self.power_one]
+        mock_deploy_steps.return_value = [
+            self.deploy_start, self.deploy_middle, self.deploy_end]
+        # These next steps are actually present on the FakeVendorB interface,
+        # and instead of just mock everything, we're actually exercising the
+        # rest of the way down including the decorator to get here.
+        fake_log_passthrough = {
+            'abortable': False, 'argsinfo': None, 'interface': 'vendor',
+            'priority': 0, 'requires_ramdisk': False,
+            'step': 'log_passthrough'
+        }
+        fake_trigger_servicewait = {
+            'abortable': False, 'argsinfo': None, 'interface': 'vendor',
+            'priority': 0, 'requires_ramdisk': True,
+            'step': 'trigger_servicewait'
+        }
+
+        expected = self.service_steps + [fake_log_passthrough,
+                                         fake_trigger_servicewait,
+                                         self.power_disable]
+        with task_manager.acquire(
+                self.context, self.node.uuid, shared=False) as task:
+            steps = conductor_steps._get_service_steps(task, enabled=False)
+
+            self.assertEqual(expected, steps)
+            mock_mgt_steps.assert_called_once_with(mock.ANY, task)
+            mock_power_steps.assert_called_once_with(mock.ANY, task)
+            mock_deploy_steps.assert_called_once_with(mock.ANY, task)
+
+    @mock.patch.object(conductor_steps, '_validate_user_service_steps',
+                       autospec=True)
+    def test_set_node_service_steps(self, mock_steps):
+        mock_steps.return_value = self.service_steps
+
+        with task_manager.acquire(
+                self.context, self.node.uuid, shared=False) as task:
+            conductor_steps.set_node_service_steps(task)
+            self.node.refresh()
+            self.assertEqual(self.service_steps,
+                             self.node.driver_internal_info['service_steps'])
+            self.assertEqual({}, self.node.service_step)
+            self.assertIsNone(
+                self.node.driver_internal_info['service_step_index'])
+            mock_steps.assert_called_once_with(task, [], disable_ramdisk=False)
