@@ -21,6 +21,7 @@ from unittest import mock
 
 import futurist
 from oslo_utils import uuidutils
+import tenacity
 
 from ironic.common import driver_factory
 from ironic.common import exception
@@ -113,7 +114,13 @@ class TaskManagerTestCase(db_base.DbTestCase):
         get_voltgt_mock.return_value = mock.sentinel.voltgt1
         build_driver_mock.return_value = mock.sentinel.driver1
 
+        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
+        def _eval_all(task):
+            return task.ports, task.portgroups, task.volume_targets, \
+                task.volume_connectors
+
         with task_manager.TaskManager(self.context, 'node-id1') as task:
+            _eval_all(task)
             reserve_mock.return_value = node2
             get_ports_mock.return_value = mock.sentinel.ports2
             get_portgroups_mock.return_value = mock.sentinel.portgroups2
@@ -121,6 +128,7 @@ class TaskManagerTestCase(db_base.DbTestCase):
             get_voltgt_mock.return_value = mock.sentinel.voltgt2
             build_driver_mock.return_value = mock.sentinel.driver2
             with task_manager.TaskManager(self.context, 'node-id2') as task2:
+                _eval_all(task2)
                 self.assertEqual(self.context, task.context)
                 self.assertEqual(self.node, task.node)
                 self.assertEqual(mock.sentinel.ports1, task.ports)
@@ -222,13 +230,13 @@ class TaskManagerTestCase(db_base.DbTestCase):
         reserve_mock.assert_called_once_with(self.context, self.host,
                                              'fake-node-id')
 
+    @mock.patch.object(tenacity, 'stop_after_attempt',
+                       return_value=tenacity.stop_after_attempt(4),
+                       autospec=True)
     def test_excl_lock_exception_patient(
-            self, get_voltgt_mock, get_volconn_mock, get_portgroups_mock,
-            get_ports_mock, build_driver_mock,
+            self, stop_mock, get_voltgt_mock, get_volconn_mock,
+            get_portgroups_mock, get_ports_mock, build_driver_mock,
             reserve_mock, release_mock, node_get_mock):
-        retry_attempts = 3
-        self.config(node_locked_retry_attempts=retry_attempts,
-                    group='conductor')
 
         # Fail on the first 3 attempts, succeed on the fourth.
         reserve_mock.side_effect = (
@@ -273,16 +281,18 @@ class TaskManagerTestCase(db_base.DbTestCase):
         reserve_mock.return_value = self.node
         get_ports_mock.side_effect = exception.IronicException('foo')
 
-        self.assertRaises(exception.IronicException,
-                          task_manager.TaskManager,
-                          self.context,
-                          'fake-node-id')
+        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
+        def _eval_ports(task):
+            return task.ports
+
+        with task_manager.TaskManager(self.context, 'fake-node-id') as task:
+            self.assertRaises(exception.IronicException, _eval_ports, task)
 
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         reserve_mock.assert_called_once_with(self.context, self.host,
                                              'fake-node-id')
         get_ports_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertFalse(build_driver_mock.called)
+        self.assertTrue(build_driver_mock.called)
         release_mock.assert_called_once_with(self.context, self.host,
                                              self.node.id)
 
@@ -293,16 +303,19 @@ class TaskManagerTestCase(db_base.DbTestCase):
         reserve_mock.return_value = self.node
         get_portgroups_mock.side_effect = exception.IronicException('foo')
 
-        self.assertRaises(exception.IronicException,
-                          task_manager.TaskManager,
-                          self.context,
-                          'fake-node-id')
+        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
+        def _eval_portgroups(task):
+            return task.portgroups
+
+        with task_manager.TaskManager(self.context, 'fake-node-id') as task:
+            self.assertRaises(exception.IronicException, _eval_portgroups,
+                              task)
 
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         reserve_mock.assert_called_once_with(self.context, self.host,
                                              'fake-node-id')
         get_portgroups_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertFalse(build_driver_mock.called)
+        self.assertTrue(build_driver_mock.called)
         release_mock.assert_called_once_with(self.context, self.host,
                                              self.node.id)
 
@@ -313,15 +326,18 @@ class TaskManagerTestCase(db_base.DbTestCase):
         reserve_mock.return_value = self.node
         get_volconn_mock.side_effect = exception.IronicException('foo')
 
-        self.assertRaises(exception.IronicException,
-                          task_manager.TaskManager,
-                          self.context,
-                          'fake-node-id')
+        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
+        def _eval_volconn(task):
+            return task.volume_connectors
+
+        with task_manager.TaskManager(self.context, 'fake-node-id') as task:
+            self.assertRaises(exception.IronicException, _eval_volconn,
+                              task)
 
         reserve_mock.assert_called_once_with(self.context, self.host,
                                              'fake-node-id')
         get_volconn_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertFalse(get_voltgt_mock.called)
+        self.assertTrue(build_driver_mock.called)
         release_mock.assert_called_once_with(self.context, self.host,
                                              self.node.id)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
@@ -333,15 +349,17 @@ class TaskManagerTestCase(db_base.DbTestCase):
         reserve_mock.return_value = self.node
         get_voltgt_mock.side_effect = exception.IronicException('foo')
 
-        self.assertRaises(exception.IronicException,
-                          task_manager.TaskManager,
-                          self.context,
-                          'fake-node-id')
+        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
+        def _eval_voltgt(task):
+            return task.volume_targets
+
+        with task_manager.TaskManager(self.context, 'fake-node-id') as task:
+            self.assertRaises(exception.IronicException, _eval_voltgt, task)
 
         reserve_mock.assert_called_once_with(self.context, self.host,
                                              'fake-node-id')
         get_voltgt_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertFalse(build_driver_mock.called)
+        self.assertTrue(build_driver_mock.called)
         release_mock.assert_called_once_with(self.context, self.host,
                                              self.node.id)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
@@ -362,8 +380,10 @@ class TaskManagerTestCase(db_base.DbTestCase):
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         reserve_mock.assert_called_once_with(self.context, self.host,
                                              'fake-node-id')
-        get_ports_mock.assert_called_once_with(self.context, self.node.id)
-        get_portgroups_mock.assert_called_once_with(self.context, self.node.id)
+        self.assertFalse(get_ports_mock.called)
+        self.assertFalse(get_portgroups_mock.called)
+        self.assertFalse(get_volconn_mock.called)
+        self.assertFalse(get_voltgt_mock.called)
         build_driver_mock.assert_called_once_with(mock.ANY)
         release_mock.assert_called_once_with(self.context, self.host,
                                              self.node.id)
@@ -423,17 +443,19 @@ class TaskManagerTestCase(db_base.DbTestCase):
         node_get_mock.return_value = self.node
         get_ports_mock.side_effect = exception.IronicException('foo')
 
-        self.assertRaises(exception.IronicException,
-                          task_manager.TaskManager,
-                          self.context,
-                          'fake-node-id',
-                          shared=True)
+        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
+        def _eval_ports(task):
+            return task.ports
+
+        with task_manager.TaskManager(self.context, 'fake-node-id',
+                                      shared=True) as task:
+            self.assertRaises(exception.IronicException, _eval_ports, task)
 
         self.assertFalse(reserve_mock.called)
         self.assertFalse(release_mock.called)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         get_ports_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertFalse(build_driver_mock.called)
+        self.assertTrue(build_driver_mock.called)
 
     def test_shared_lock_get_portgroups_exception(
             self, get_voltgt_mock, get_volconn_mock, get_portgroups_mock,
@@ -442,17 +464,20 @@ class TaskManagerTestCase(db_base.DbTestCase):
         node_get_mock.return_value = self.node
         get_portgroups_mock.side_effect = exception.IronicException('foo')
 
-        self.assertRaises(exception.IronicException,
-                          task_manager.TaskManager,
-                          self.context,
-                          'fake-node-id',
-                          shared=True)
+        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
+        def _eval_portgroups(task):
+            return task.portgroups
+
+        with task_manager.TaskManager(self.context, 'fake-node-id',
+                                      shared=True) as task:
+            self.assertRaises(exception.IronicException, _eval_portgroups,
+                              task)
 
         self.assertFalse(reserve_mock.called)
         self.assertFalse(release_mock.called)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         get_portgroups_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertFalse(build_driver_mock.called)
+        self.assertTrue(build_driver_mock.called)
 
     def test_shared_lock_get_volconn_exception(
             self, get_voltgt_mock, get_volconn_mock, get_portgroups_mock,
@@ -461,17 +486,19 @@ class TaskManagerTestCase(db_base.DbTestCase):
         node_get_mock.return_value = self.node
         get_volconn_mock.side_effect = exception.IronicException('foo')
 
-        self.assertRaises(exception.IronicException,
-                          task_manager.TaskManager,
-                          self.context,
-                          'fake-node-id',
-                          shared=True)
+        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
+        def _eval_volconn(task):
+            return task.volume_connectors
+
+        with task_manager.TaskManager(self.context, 'fake-node-id',
+                                      shared=True) as task:
+            self.assertRaises(exception.IronicException, _eval_volconn, task)
 
         self.assertFalse(reserve_mock.called)
         self.assertFalse(release_mock.called)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         get_volconn_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertFalse(get_voltgt_mock.called)
+        self.assertTrue(build_driver_mock.called)
 
     def test_shared_lock_get_voltgt_exception(
             self, get_voltgt_mock, get_volconn_mock, get_portgroups_mock,
@@ -480,17 +507,19 @@ class TaskManagerTestCase(db_base.DbTestCase):
         node_get_mock.return_value = self.node
         get_voltgt_mock.side_effect = exception.IronicException('foo')
 
-        self.assertRaises(exception.IronicException,
-                          task_manager.TaskManager,
-                          self.context,
-                          'fake-node-id',
-                          shared=True)
+        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
+        def _eval_voltgt(task):
+            return task.volume_targets
+
+        with task_manager.TaskManager(self.context, 'fake-node-id',
+                                      shared=True) as task:
+            self.assertRaises(exception.IronicException, _eval_voltgt, task)
 
         self.assertFalse(reserve_mock.called)
         self.assertFalse(release_mock.called)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         get_voltgt_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertFalse(build_driver_mock.called)
+        self.assertTrue(build_driver_mock.called)
 
     def test_shared_lock_build_driver_exception(
             self, get_voltgt_mock, get_volconn_mock, get_portgroups_mock,
@@ -509,10 +538,10 @@ class TaskManagerTestCase(db_base.DbTestCase):
         self.assertFalse(reserve_mock.called)
         self.assertFalse(release_mock.called)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
-        get_ports_mock.assert_called_once_with(self.context, self.node.id)
-        get_portgroups_mock.assert_called_once_with(self.context, self.node.id)
-        get_volconn_mock.assert_called_once_with(self.context, self.node.id)
-        get_voltgt_mock.assert_called_once_with(self.context, self.node.id)
+        self.assertFalse(get_ports_mock.called)
+        self.assertFalse(get_portgroups_mock.called)
+        self.assertFalse(get_voltgt_mock.called)
+        self.assertFalse(get_volconn_mock.called)
         build_driver_mock.assert_called_once_with(mock.ANY)
 
     def test_upgrade_lock(
