@@ -18,8 +18,8 @@ Test class for DRAC inspection interface
 from unittest import mock
 
 from dracclient import exceptions as drac_exceptions
-from oslo_utils import importutils
 from oslo_utils import units
+import sushy
 
 from ironic.common import exception
 from ironic.common import states
@@ -33,8 +33,6 @@ from ironic import objects
 from ironic.tests.unit.drivers.modules.drac import utils as test_utils
 from ironic.tests.unit.objects import utils as obj_utils
 
-sushy = importutils.try_import('sushy')
-
 INFO_DICT = test_utils.INFO_DICT
 
 
