@@ -15,31 +15,28 @@
 Test class for DRAC job specific methods
 """
 
+from unittest import mock
+
 from dracclient import exceptions as drac_exceptions
-import mock
 
 from ironic.common import exception
 from ironic.conductor import task_manager
 from ironic.drivers.modules.drac import common as drac_common
 from ironic.drivers.modules.drac import job as drac_job
-from ironic.tests.unit.conductor import mgr_utils
-from ironic.tests.unit.db import base as db_base
-from ironic.tests.unit.db import utils as db_utils
 from ironic.tests.unit.drivers.modules.drac import utils as test_utils
 from ironic.tests.unit.objects import utils as obj_utils
 
-INFO_DICT = db_utils.get_test_drac_info()
+INFO_DICT = test_utils.INFO_DICT
 
 
 @mock.patch.object(drac_common, 'get_drac_client', spec_set=True,
                    autospec=True)
-class DracJobTestCase(db_base.DbTestCase):
+class DracJobTestCase(test_utils.BaseDracTest):
 
     def setUp(self):
         super(DracJobTestCase, self).setUp()
-        mgr_utils.mock_the_extension_manager(driver='fake_drac')
         self.node = obj_utils.create_test_node(self.context,
-                                               driver='fake_drac',
+                                               driver='idrac',
                                                driver_info=INFO_DICT)
         self.job_dict = {
             'id': 'JID_001436912645',
@@ -47,9 +44,9 @@ class DracJobTestCase(db_base.DbTestCase):
             'start_time': '00000101000000',
             'until_time': 'TIME_NA',
             'message': 'Job in progress',
-            'state': 'Running',
+            'status': 'Running',
             'percent_complete': 34}
-        self.job = test_utils.dict_to_namedtuple(values=self.job_dict)
+        self.job = test_utils.make_job(self.job_dict)
 
     def test_get_job(self, mock_get_drac_client):
         mock_client = mock.Mock()
@@ -115,16 +112,34 @@ class DracJobTestCase(db_base.DbTestCase):
         self.assertRaises(exception.DracOperationError,
                           drac_job.validate_job_queue, self.node)
 
+    def test_validate_job_queue_name_prefix(self, mock_get_drac_client):
+        mock_client = mock.Mock()
+        mock_get_drac_client.return_value = mock_client
+        mock_client.list_jobs.return_value = [self.job]
+
+        drac_job.validate_job_queue(self.node, name_prefix='Fake')
+
+        mock_client.list_jobs.assert_called_once_with(only_unfinished=True)
+
+    def test_validate_job_queue_name_prefix_invalid(self,
+                                                    mock_get_drac_client):
+        mock_client = mock.Mock()
+        mock_get_drac_client.return_value = mock_client
+        mock_client.list_jobs.return_value = [self.job]
+
+        self.assertRaises(exception.DracOperationError,
+                          drac_job.validate_job_queue, self.node,
+                          name_prefix='ConfigBIOS')
+
 
 @mock.patch.object(drac_common, 'get_drac_client', spec_set=True,
                    autospec=True)
-class DracVendorPassthruJobTestCase(db_base.DbTestCase):
+class DracVendorPassthruJobTestCase(test_utils.BaseDracTest):
 
     def setUp(self):
         super(DracVendorPassthruJobTestCase, self).setUp()
-        mgr_utils.mock_the_extension_manager(driver='fake_drac')
         self.node = obj_utils.create_test_node(self.context,
-                                               driver='fake_drac',
+                                               driver='idrac',
                                                driver_info=INFO_DICT)
         self.job_dict = {
             'id': 'JID_001436912645',
@@ -132,9 +147,9 @@ class DracVendorPassthruJobTestCase(db_base.DbTestCase):
             'start_time': '00000101000000',
             'until_time': 'TIME_NA',
             'message': 'Job in progress',
-            'state': 'Running',
+            'status': 'Running',
             'percent_complete': 34}
-        self.job = test_utils.dict_to_namedtuple(values=self.job_dict)
+        self.job = test_utils.make_job(self.job_dict)
 
     def test_list_unfinished_jobs(self, mock_get_drac_client):
         mock_client = mock.Mock()
