@@ -423,7 +423,7 @@ class IloBiosTestCase(test_common.BaseIloTest):
             step = 'apply_configuration'
             task.driver.bios._execute_post_boot_bios_step(task, step)
             driver_info = task.node.driver_internal_info
-            self.assertTrue('apply_bios' not in driver_info)
+            self.assertNotIn('apply_bios', driver_info)
             ilo_object_mock.get_bios_settings_result.assert_called_once_with()
 
     @mock.patch.object(ilo_common, 'get_ilo_object', spec_set=True,
@@ -441,7 +441,7 @@ class IloBiosTestCase(test_common.BaseIloTest):
             step = 'factory_reset'
             task.driver.bios._execute_post_boot_bios_step(task, step)
             driver_info = task.node.driver_internal_info
-            self.assertTrue('reset_bios' not in driver_info)
+            self.assertNotIn('reset_bios', driver_info)
             ilo_object_mock.get_bios_settings_result.assert_called_once_with()
 
     @mock.patch.object(ilo_common, 'get_ilo_object', spec_set=True,
@@ -463,8 +463,7 @@ class IloBiosTestCase(test_common.BaseIloTest):
             self.assertRaises(exept,
                               task.driver.bios._execute_post_boot_bios_step,
                               task, step)
-            self.assertTrue(
-                'apply_bios' not in task.node.driver_internal_info)
+            self.assertNotIn('apply_bios', task.node.driver_internal_info)
 
     def test__execute_post_boot_bios_step_invalid_cleaning(self):
         self.node.clean_step = {'priority': 100, 'interface': 'bios',
@@ -503,8 +502,7 @@ class IloBiosTestCase(test_common.BaseIloTest):
             self.assertRaises(exept,
                               task.driver.bios._execute_post_boot_bios_step,
                               task, step)
-            self.assertTrue(
-                'apply_bios' not in task.node.driver_internal_info)
+            self.assertNotIn('apply_bios', task.node.driver_internal_info)
 
     def test__execute_post_boot_bios_step_iloobj_failed_cleaning(self):
         self.node.clean_step = {'priority': 100, 'interface': 'bios',
@@ -543,8 +541,7 @@ class IloBiosTestCase(test_common.BaseIloTest):
                                  [],
                                  [], mdobj,
                                  ilo_object_mock.get_bios_settings_result)
-            self.assertTrue(
-                'apply_bios' not in task.node.driver_internal_info)
+            self.assertNotIn('apply_bios', task.node.driver_internal_info)
 
     def test__execute_post_boot_bios_get_settings_error_cleaning(
             self):
@@ -584,8 +581,7 @@ class IloBiosTestCase(test_common.BaseIloTest):
             self.assertRaises(exept,
                               task.driver.bios._execute_post_boot_bios_step,
                               task, step)
-            self.assertTrue(
-                'reset_bios' not in task.node.driver_internal_info)
+            self.assertNotIn('reset_bios', task.node.driver_internal_info)
 
     def test__execute_post_boot_bios_get_settings_failed_cleaning(
             self):
@@ -601,10 +597,11 @@ class IloBiosTestCase(test_common.BaseIloTest):
         self.node.save()
         self._test__execute_post_boot_bios_get_settings_failed()
 
-    @mock.patch.object(objects.BIOSSettingList, 'create')
-    @mock.patch.object(objects.BIOSSettingList, 'save')
-    @mock.patch.object(objects.BIOSSettingList, 'delete')
-    @mock.patch.object(objects.BIOSSettingList, 'sync_node_setting')
+    @mock.patch.object(objects.BIOSSettingList, 'create', autospec=True)
+    @mock.patch.object(objects.BIOSSettingList, 'save', autospec=True)
+    @mock.patch.object(objects.BIOSSettingList, 'delete', autospec=True)
+    @mock.patch.object(objects.BIOSSettingList, 'sync_node_setting',
+                       autospec=True)
     @mock.patch.object(ilo_common, 'get_ilo_object', autospec=True)
     def test_cache_bios_settings(self, get_ilo_object_mock, sync_node_mock,
                                  delete_mock, save_mock, create_mock):
