@@ -42,6 +42,7 @@ class InspectHardwareTestCase(db_base.DbTestCase):
         self.driver = self.task.driver
 
     def test_unmanaged_ok(self, mock_create_ports_if_not_exist):
+        CONF.set_override('require_managed_boot', False, group='inspector')
         self.driver.boot.validate_inspection.side_effect = (
             exception.UnsupportedDriverExtension(''))
         self.assertEqual(states.INSPECTWAIT,
@@ -58,6 +59,12 @@ class InspectHardwareTestCase(db_base.DbTestCase):
         self.assertFalse(self.driver.network.remove_inspection_network.called)
         self.assertFalse(self.driver.boot.clean_up_ramdisk.called)
 
+    def test_unmanaged_disallowed(self, mock_create_ports_if_not_exist):
+        self.driver.boot.validate_inspection.side_effect = (
+            exception.UnsupportedDriverExtension(''))
+        self.assertRaises(exception.UnsupportedDriverExtension,
+                          self.iface.inspect_hardware, self.task)
+
     @mock.patch.object(deploy_utils, 'get_ironic_api_url', autospec=True)
     def test_managed_ok(self, mock_get_url, mock_create_ports_if_not_exist):
         endpoint = 'http://192.169.0.42:6385/v1'
@@ -129,43 +136,3 @@ class ContinueInspectionTestCase(db_base.DbTestCase):
             self.assertEqual(states.INSPECTING, task.node.provision_state)
 
         self.assertIsNone(result)
-
-
-@mock.patch.object(common, 'tear_down_managed_boot', autospec=True)
-class AbortInspectionTestCase(db_base.DbTestCase):
-    def setUp(self):
-        super().setUp()
-        CONF.set_override('enabled_inspect_interfaces',
-                          ['agent', 'no-inspect'])
-        self.node = obj_utils.create_test_node(
-            self.context,
-            driver_internal_info={
-                'lookup_bmc_addresses': [42],
-            },
-            inspect_interface='agent',
-            provision_state=states.INSPECTWAIT)
-        self.iface = inspector.AgentInspect()
-
-    def test_success(self, mock_tear_down):
-        mock_tear_down.return_value = None
-        with task_manager.acquire(self.context, self.node.id) as task:
-            self.iface.abort(task)
-            mock_tear_down.assert_called_once_with(task)
-
-        self.node.refresh()
-        # Keep the state - it will be changed on the conductor level
-        self.assertEqual(states.INSPECTWAIT, self.node.provision_state)
-        self.assertNotIn('lookup_bmc_addresses',
-                         self.node.driver_internal_info)
-
-    def test_cleanup_failed(self, mock_tear_down):
-        mock_tear_down.return_value = ['boom']
-        with task_manager.acquire(self.context, self.node.id) as task:
-            self.iface.abort(task)
-            mock_tear_down.assert_called_once_with(task)
-
-        self.node.refresh()
-        self.assertEqual(states.INSPECTFAIL, self.node.provision_state)
-        self.assertIn('boom', self.node.last_error)
-        self.assertNotIn('lookup_bmc_addresses',
-                         self.node.driver_internal_info)
