@@ -20,8 +20,8 @@ import time
 from unittest import mock
 
 from oslo_config import cfg
-from oslo_utils import importutils
 import requests
+import sushy
 
 from ironic.common import exception
 from ironic.drivers.modules.redfish import utils as redfish_utils
@@ -29,8 +29,6 @@ from ironic.tests.unit.db import base as db_base
 from ironic.tests.unit.db import utils as db_utils
 from ironic.tests.unit.objects import utils as obj_utils
 
-sushy = importutils.try_import('sushy')
-
 INFO_DICT = db_utils.get_test_redfish_info()
 
 
