@@ -23,11 +23,9 @@ import time
 from unittest import mock
 import uuid
 
-from oslo_config import cfg
 from oslo_utils import uuidutils
 
 from ironic.common import exception
-from ironic.common import image_format_inspector
 from ironic.common import image_service
 from ironic.common import images
 from ironic.common import utils
@@ -157,7 +155,7 @@ class TestImageCacheFetch(BaseTest):
         mock_download.assert_called_once_with(
             self.cache, self.uuid, self.master_path, self.dest_path,
             mock_image_service.return_value.show.return_value,
-            ctx=None, force_raw=True, expected_format=None)
+            ctx=None, force_raw=True)
         mock_clean_up.assert_called_once_with(self.cache)
         mock_image_service.assert_called_once_with(self.uuid, context=None)
         mock_image_service.return_value.show.assert_called_once_with(self.uuid)
@@ -179,7 +177,7 @@ class TestImageCacheFetch(BaseTest):
         mock_download.assert_called_once_with(
             self.cache, self.uuid, self.master_path, self.dest_path,
             mock_image_service.return_value.show.return_value,
-            ctx=None, force_raw=True, expected_format=None)
+            ctx=None, force_raw=True)
         mock_clean_up.assert_called_once_with(self.cache)
 
     def test_fetch_image_not_uuid(self, mock_download, mock_clean_up,
@@ -192,7 +190,7 @@ class TestImageCacheFetch(BaseTest):
         mock_download.assert_called_once_with(
             self.cache, href, master_path, self.dest_path,
             mock_image_service.return_value.show.return_value,
-            ctx=None, force_raw=True, expected_format=None)
+            ctx=None, force_raw=True)
         self.assertTrue(mock_clean_up.called)
 
     def test_fetch_image_not_uuid_no_force_raw(self, mock_download,
@@ -205,7 +203,7 @@ class TestImageCacheFetch(BaseTest):
         mock_download.assert_called_once_with(
             self.cache, href, master_path, self.dest_path,
             mock_image_service.return_value.show.return_value,
-            ctx=None, force_raw=False, expected_format=None)
+            ctx=None, force_raw=False)
         self.assertTrue(mock_clean_up.called)
 
 
@@ -574,7 +572,7 @@ class TestImageCacheCleanUp(base.TestCase):
 
         self.assertEqual(image_cache._cache_cleanup_list[0][1], Cache2)
 
-        # The order of caches with same prioirty is not deterministic.
+        # The order of caches with same priority is not deterministic.
         item_possibilities = [Cache1, Cache3]
         second_item_actual = image_cache._cache_cleanup_list[1][1]
         self.assertIn(second_item_actual, item_possibilities)
@@ -756,22 +754,16 @@ class CleanupImageCacheTestCase(base.TestCase):
 
 class TestFetchCleanup(base.TestCase):
 
-    @mock.patch.object(image_format_inspector, 'detect_file_format',
-                       autospec=True)
-    @mock.patch.object(images, 'image_show', autospec=True)
     @mock.patch.object(os, 'remove', autospec=True)
     @mock.patch.object(images, 'converted_size', autospec=True)
     @mock.patch.object(images, 'fetch', autospec=True)
     @mock.patch.object(images, 'image_to_raw', autospec=True)
+    @mock.patch.object(images, 'force_raw_will_convert', autospec=True,
+                       return_value=True)
     @mock.patch.object(image_cache, '_clean_up_caches', autospec=True)
     def test__fetch(
-            self, mock_clean, mock_raw, mock_fetch,
-            mock_size, mock_remove, mock_show, mock_format_inspector):
-        image_check = mock.MagicMock()
-        image_check.__str__.side_effect = iter(['qcow2', 'raw'])
-        image_check.safety_check.return_value = True
-        mock_format_inspector.return_value = image_check
-        mock_show.return_value = {}
+            self, mock_clean, mock_will_convert, mock_raw, mock_fetch,
+            mock_size, mock_remove):
         mock_size.return_value = 100
         image_cache._fetch('fake', 'fake-uuid', '/foo/bar', force_raw=True)
         mock_fetch.assert_called_once_with('fake', 'fake-uuid',
@@ -779,31 +771,21 @@ class TestFetchCleanup(base.TestCase):
         mock_clean.assert_called_once_with('/foo', 100)
         mock_raw.assert_called_once_with('fake-uuid', '/foo/bar',
                                          '/foo/bar.part')
+        mock_will_convert.assert_called_once_with('fake-uuid', '/foo/bar.part')
         mock_remove.assert_not_called()
-        mock_show.assert_called_once_with('fake', 'fake-uuid')
-        mock_format_inspector.assert_called_once_with('/foo/bar.part')
-        image_check.safety_check.assert_called_once()
-        self.assertEqual(1, image_check.__str__.call_count)
 
-    @mock.patch.object(image_format_inspector, 'detect_file_format',
-                       autospec=True)
-    @mock.patch.object(images, 'image_show', autospec=True)
     @mock.patch.object(os, 'remove', autospec=True)
+    @mock.patch.object(os.path, 'exists', autospec=True)
     @mock.patch.object(images, 'converted_size', autospec=True)
     @mock.patch.object(images, 'fetch', autospec=True)
     @mock.patch.object(images, 'image_to_raw', autospec=True)
+    @mock.patch.object(images, 'force_raw_will_convert', autospec=True,
+                       return_value=True)
     @mock.patch.object(image_cache, '_clean_up_caches', autospec=True)
-    def test__fetch_deep_inspection_disabled(
-            self, mock_clean, mock_raw, mock_fetch,
-            mock_size, mock_remove, mock_show, mock_format_inspector):
-        cfg.CONF.set_override(
-            'disable_deep_image_inspection', True,
-            group='conductor')
-        image_check = mock.MagicMock()
-        image_check.__str__.return_value = 'qcow2'
-        image_check.safety_check.return_value = True
-        mock_format_inspector.return_value = image_check
-        mock_show.return_value = {}
+    def test__fetch_part_already_exists(
+            self, mock_clean, mock_will_convert, mock_raw, mock_fetch,
+            mock_size, mock_exists, mock_remove):
+        mock_exists.return_value = True
         mock_size.return_value = 100
         image_cache._fetch('fake', 'fake-uuid', '/foo/bar', force_raw=True)
         mock_fetch.assert_called_once_with('fake', 'fake-uuid',
@@ -811,114 +793,37 @@ class TestFetchCleanup(base.TestCase):
         mock_clean.assert_called_once_with('/foo', 100)
         mock_raw.assert_called_once_with('fake-uuid', '/foo/bar',
                                          '/foo/bar.part')
-        mock_remove.assert_not_called()
-        mock_show.assert_not_called()
-        mock_format_inspector.assert_called_once_with('/foo/bar.part')
-        image_check.safety_check.assert_not_called()
-        self.assertEqual(1, image_check.__str__.call_count)
+        mock_will_convert.assert_called_once_with('fake-uuid', '/foo/bar.part')
+        self.assertEqual(1, mock_exists.call_count)
+        self.assertEqual(1, mock_remove.call_count)
 
-    @mock.patch.object(os, 'rename', autospec=True)
-    @mock.patch.object(image_format_inspector, 'detect_file_format',
-                       autospec=True)
-    @mock.patch.object(images, 'image_show', autospec=True)
     @mock.patch.object(images, 'converted_size', autospec=True)
     @mock.patch.object(images, 'fetch', autospec=True)
     @mock.patch.object(images, 'image_to_raw', autospec=True)
+    @mock.patch.object(images, 'force_raw_will_convert', autospec=True,
+                       return_value=False)
     @mock.patch.object(image_cache, '_clean_up_caches', autospec=True)
     def test__fetch_already_raw(
-            self, mock_clean, mock_raw, mock_fetch,
-            mock_size, mock_show, mock_format_inspector,
-            mock_rename):
-        mock_show.return_value = {'disk_format': 'raw'}
-        image_check = mock.MagicMock()
-        image_check.__str__.return_value = 'raw'
-        image_check.safety_check.return_value = True
-        mock_format_inspector.return_value = image_check
+            self, mock_clean, mock_will_convert, mock_raw, mock_fetch,
+            mock_size):
         image_cache._fetch('fake', 'fake-uuid', '/foo/bar', force_raw=True)
         mock_fetch.assert_called_once_with('fake', 'fake-uuid',
                                            '/foo/bar.part', force_raw=False)
         mock_clean.assert_not_called()
         mock_size.assert_not_called()
-        mock_raw.assert_not_called()
-        mock_show.assert_called_once_with('fake', 'fake-uuid')
-        mock_format_inspector.assert_called_once_with('/foo/bar.part')
-        image_check.safety_check.assert_called_once()
-        self.assertEqual(1, image_check.__str__.call_count)
-        mock_rename.assert_called_once_with('/foo/bar.part', '/foo/bar')
+        mock_raw.assert_called_once_with('fake-uuid', '/foo/bar',
+                                         '/foo/bar.part')
+        mock_will_convert.assert_called_once_with('fake-uuid', '/foo/bar.part')
 
-    @mock.patch.object(image_format_inspector, 'detect_file_format',
-                       autospec=True)
-    @mock.patch.object(images, 'image_show', autospec=True)
-    @mock.patch.object(images, 'converted_size', autospec=True)
-    @mock.patch.object(images, 'fetch', autospec=True)
-    @mock.patch.object(images, 'image_to_raw', autospec=True)
-    @mock.patch.object(image_cache, '_clean_up_caches', autospec=True)
-    def test__fetch_format_does_not_match_glance(
-            self, mock_clean, mock_raw, mock_fetch,
-            mock_size, mock_show, mock_format_inspector):
-        mock_show.return_value = {'disk_format': 'raw'}
-        image_check = mock.MagicMock()
-        image_check.__str__.return_value = 'qcow2'
-        image_check.safety_check.return_value = True
-        mock_format_inspector.return_value = image_check
-        self.assertRaises(exception.InvalidImage,
-                          image_cache._fetch,
-                          'fake', 'fake-uuid',
-                          '/foo/bar', force_raw=True)
-        mock_fetch.assert_called_once_with('fake', 'fake-uuid',
-                                           '/foo/bar.part', force_raw=False)
-        mock_clean.assert_not_called()
-        mock_size.assert_not_called()
-        mock_raw.assert_not_called()
-        mock_show.assert_called_once_with('fake', 'fake-uuid')
-        mock_format_inspector.assert_called_once_with('/foo/bar.part')
-        image_check.safety_check.assert_called_once()
-        self.assertEqual(1, image_check.__str__.call_count)
-
-    @mock.patch.object(image_format_inspector, 'detect_file_format',
-                       autospec=True)
-    @mock.patch.object(images, 'image_show', autospec=True)
-    @mock.patch.object(images, 'converted_size', autospec=True)
-    @mock.patch.object(images, 'fetch', autospec=True)
-    @mock.patch.object(images, 'image_to_raw', autospec=True)
-    @mock.patch.object(image_cache, '_clean_up_caches', autospec=True)
-    def test__fetch_not_safe_image(
-            self, mock_clean, mock_raw, mock_fetch,
-            mock_size, mock_show, mock_format_inspector):
-        mock_show.return_value = {'disk_format': 'qcow2'}
-        image_check = mock.MagicMock()
-        image_check.__str__.return_value = 'qcow2'
-        image_check.safety_check.return_value = False
-        mock_format_inspector.return_value = image_check
-        self.assertRaises(exception.InvalidImage,
-                          image_cache._fetch,
-                          'fake', 'fake-uuid',
-                          '/foo/bar', force_raw=True)
-        mock_fetch.assert_called_once_with('fake', 'fake-uuid',
-                                           '/foo/bar.part', force_raw=False)
-        mock_clean.assert_not_called()
-        mock_size.assert_not_called()
-        mock_raw.assert_not_called()
-        mock_show.assert_called_once_with('fake', 'fake-uuid')
-        mock_format_inspector.assert_called_once_with('/foo/bar.part')
-        image_check.safety_check.assert_called_once()
-        self.assertEqual(0, image_check.__str__.call_count)
-
-    @mock.patch.object(image_format_inspector, 'detect_file_format',
-                       autospec=True)
-    @mock.patch.object(images, 'image_show', autospec=True)
     @mock.patch.object(images, 'converted_size', autospec=True)
     @mock.patch.object(images, 'fetch', autospec=True)
     @mock.patch.object(images, 'image_to_raw', autospec=True)
+    @mock.patch.object(images, 'force_raw_will_convert', autospec=True,
+                       return_value=True)
     @mock.patch.object(image_cache, '_clean_up_caches', autospec=True)
     def test__fetch_estimate_fallback(
-            self, mock_clean, mock_raw, mock_fetch,
-            mock_size, mock_show, mock_format_inspector):
-        mock_show.return_value = {'disk_format': 'qcow2'}
-        image_check = mock.MagicMock()
-        image_check.__str__.side_effect = iter(['qcow2', 'raw'])
-        image_check.safety_check.return_value = True
-        mock_format_inspector.return_value = image_check
+            self, mock_clean, mock_will_convert, mock_raw, mock_fetch,
+            mock_size):
         mock_size.side_effect = [100, 10]
         mock_clean.side_effect = [exception.InsufficientDiskSpace(), None]
 
@@ -935,69 +840,4 @@ class TestFetchCleanup(base.TestCase):
         ])
         mock_raw.assert_called_once_with('fake-uuid', '/foo/bar',
                                          '/foo/bar.part')
-        mock_show.assert_called_once_with('fake', 'fake-uuid')
-        mock_format_inspector.assert_called_once_with('/foo/bar.part')
-        image_check.safety_check.assert_called_once()
-        self.assertEqual(1, image_check.__str__.call_count)
-
-    @mock.patch.object(os, 'rename', autospec=True)
-    @mock.patch.object(image_format_inspector, 'detect_file_format',
-                       autospec=True)
-    @mock.patch.object(images, 'image_show', autospec=True)
-    @mock.patch.object(os, 'remove', autospec=True)
-    @mock.patch.object(images, 'converted_size', autospec=True)
-    @mock.patch.object(images, 'fetch', autospec=True)
-    @mock.patch.object(images, 'image_to_raw', autospec=True)
-    @mock.patch.object(image_cache, '_clean_up_caches', autospec=True)
-    def test__fetch_ramdisk_kernel(
-            self, mock_clean, mock_raw, mock_fetch,
-            mock_size, mock_remove, mock_show, mock_format_inspector,
-            mock_rename):
-        image_check = mock.MagicMock()
-        image_check.__str__.return_value = 'raw'
-        image_check.safety_check.return_value = True
-        mock_format_inspector.return_value = image_check
-        mock_show.return_value = {'disk_format': 'aki'}
-        mock_size.return_value = 100
-        image_cache._fetch('fake', 'fake-uuid', '/foo/bar', force_raw=True)
-        mock_fetch.assert_called_once_with('fake', 'fake-uuid',
-                                           '/foo/bar.part', force_raw=False)
-        mock_clean.assert_not_called()
-        mock_raw.assert_not_called()
-        mock_remove.assert_not_called()
-        mock_show.assert_called_once_with('fake', 'fake-uuid')
-        mock_format_inspector.assert_called_once_with('/foo/bar.part')
-        image_check.safety_check.assert_called_once()
-        self.assertEqual(1, image_check.__str__.call_count)
-        mock_rename.assert_called_once_with('/foo/bar.part', '/foo/bar')
-
-    @mock.patch.object(os, 'rename', autospec=True)
-    @mock.patch.object(image_format_inspector, 'detect_file_format',
-                       autospec=True)
-    @mock.patch.object(images, 'image_show', autospec=True)
-    @mock.patch.object(os, 'remove', autospec=True)
-    @mock.patch.object(images, 'converted_size', autospec=True)
-    @mock.patch.object(images, 'fetch', autospec=True)
-    @mock.patch.object(images, 'image_to_raw', autospec=True)
-    @mock.patch.object(image_cache, '_clean_up_caches', autospec=True)
-    def test__fetch_ramdisk_image(
-            self, mock_clean, mock_raw, mock_fetch,
-            mock_size, mock_remove, mock_show, mock_format_inspector,
-            mock_rename):
-        image_check = mock.MagicMock()
-        image_check.__str__.return_value = 'raw'
-        image_check.safety_check.return_value = True
-        mock_format_inspector.return_value = image_check
-        mock_show.return_value = {'disk_format': 'ari'}
-        mock_size.return_value = 100
-        image_cache._fetch('fake', 'fake-uuid', '/foo/bar', force_raw=True)
-        mock_fetch.assert_called_once_with('fake', 'fake-uuid',
-                                           '/foo/bar.part', force_raw=False)
-        mock_clean.assert_not_called()
-        mock_raw.assert_not_called()
-        mock_remove.assert_not_called()
-        mock_show.assert_called_once_with('fake', 'fake-uuid')
-        mock_format_inspector.assert_called_once_with('/foo/bar.part')
-        image_check.safety_check.assert_called_once()
-        self.assertEqual(1, image_check.__str__.call_count)
-        mock_rename.assert_called_once_with('/foo/bar.part', '/foo/bar')
+        mock_will_convert.assert_called_once_with('fake-uuid', '/foo/bar.part')
