@@ -16,12 +16,13 @@
 Test class for iLO Drivers
 """
 
+from oslo_utils import uuidutils
+
 from ironic.conductor import task_manager
 from ironic.drivers import ilo
 from ironic.drivers.modules import agent
 from ironic.drivers.modules.ilo import raid
 from ironic.drivers.modules import inspector
-from ironic.drivers.modules import iscsi_deploy
 from ironic.drivers.modules import noop
 from ironic.tests.unit.db import base as db_base
 from ironic.tests.unit.objects import utils as obj_utils
@@ -35,7 +36,7 @@ class IloHardwareTestCase(db_base.DbTestCase):
                     enabled_boot_interfaces=['ilo-virtual-media', 'ilo-pxe'],
                     enabled_bios_interfaces=['no-bios', 'ilo'],
                     enabled_console_interfaces=['ilo'],
-                    enabled_deploy_interfaces=['iscsi', 'direct'],
+                    enabled_deploy_interfaces=['ansible', 'direct'],
                     enabled_inspect_interfaces=['ilo'],
                     enabled_management_interfaces=['ilo'],
                     enabled_power_interfaces=['ilo'],
@@ -54,7 +55,7 @@ class IloHardwareTestCase(db_base.DbTestCase):
             self.assertIsInstance(task.driver.console,
                                   ilo.console.IloConsoleInterface)
             self.assertIsInstance(task.driver.deploy,
-                                  iscsi_deploy.ISCSIDeploy)
+                                  agent.AgentDeploy)
             self.assertIsInstance(task.driver.inspect,
                                   ilo.inspect.IloInspect)
             self.assertIsInstance(task.driver.management,
@@ -72,7 +73,6 @@ class IloHardwareTestCase(db_base.DbTestCase):
         self.config(enabled_inspect_interfaces=['inspector', 'ilo'])
         node = obj_utils.create_test_node(
             self.context, driver='ilo',
-            deploy_interface='direct',
             inspect_interface='inspector',
             raid_interface='agent',
             vendor_interface='no-vendor')
@@ -107,7 +107,7 @@ class IloHardwareTestCase(db_base.DbTestCase):
             self.assertIsInstance(task.driver.console,
                                   ilo.console.IloConsoleInterface)
             self.assertIsInstance(task.driver.deploy,
-                                  iscsi_deploy.ISCSIDeploy)
+                                  agent.AgentDeploy)
             self.assertIsInstance(task.driver.inspect,
                                   ilo.inspect.IloInspect)
             self.assertIsInstance(task.driver.management,
@@ -125,7 +125,6 @@ class IloHardwareTestCase(db_base.DbTestCase):
         self.config(enabled_inspect_interfaces=['inspector', 'ilo'])
         node = obj_utils.create_test_node(
             self.context, driver='ilo',
-            deploy_interface='direct',
             rescue_interface='agent',
             raid_interface='agent')
         with task_manager.acquire(self.context, node.id) as task:
@@ -153,7 +152,6 @@ class IloHardwareTestCase(db_base.DbTestCase):
             self.context, driver='ilo',
             boot_interface='ilo-pxe',
             bios_interface='no-bios',
-            deploy_interface='direct',
             raid_interface='agent')
         with task_manager.acquire(self.context, node.id) as task:
             self.assertIsInstance(task.driver.boot,
@@ -175,9 +173,9 @@ class Ilo5HardwareTestCase(db_base.DbTestCase):
         self.config(enabled_hardware_types=['ilo5'],
                     enabled_boot_interfaces=['ilo-virtual-media', 'ilo-pxe'],
                     enabled_console_interfaces=['ilo'],
-                    enabled_deploy_interfaces=['iscsi', 'direct'],
+                    enabled_deploy_interfaces=['ansible', 'direct'],
                     enabled_inspect_interfaces=['ilo'],
-                    enabled_management_interfaces=['ilo'],
+                    enabled_management_interfaces=['ilo5'],
                     enabled_power_interfaces=['ilo'],
                     enabled_raid_interfaces=['ilo5'],
                     enabled_rescue_interfaces=['no-rescue', 'agent'],
@@ -186,27 +184,31 @@ class Ilo5HardwareTestCase(db_base.DbTestCase):
     def test_default_interfaces(self):
         node = obj_utils.create_test_node(self.context, driver='ilo5')
         with task_manager.acquire(self.context, node.id) as task:
-            self.assertIsInstance(task.driver.raid, raid.Ilo5RAID)
-
-    def test_override_with_no_raid(self):
-        self.config(enabled_raid_interfaces=['no-raid', 'ilo5'])
-        node = obj_utils.create_test_node(self.context, driver='ilo5',
-                                          raid_interface='no-raid')
-        with task_manager.acquire(self.context, node.id) as task:
-            self.assertIsInstance(task.driver.raid, noop.NoRAID)
             self.assertIsInstance(task.driver.boot,
                                   ilo.boot.IloVirtualMediaBoot)
             self.assertIsInstance(task.driver.console,
                                   ilo.console.IloConsoleInterface)
             self.assertIsInstance(task.driver.deploy,
-                                  iscsi_deploy.ISCSIDeploy)
+                                  agent.AgentDeploy)
             self.assertIsInstance(task.driver.inspect,
                                   ilo.inspect.IloInspect)
             self.assertIsInstance(task.driver.management,
                                   ilo.management.IloManagement)
             self.assertIsInstance(task.driver.power,
                                   ilo.power.IloPower)
+            self.assertIsInstance(task.driver.raid, raid.Ilo5RAID)
             self.assertIsInstance(task.driver.rescue,
                                   noop.NoRescue)
             self.assertIsInstance(task.driver.vendor,
                                   ilo.vendor.VendorPassthru)
+
+    def test_override_raid(self):
+        self.config(enabled_raid_interfaces=['agent', 'no-raid', 'ilo5'])
+        for iface, impl in [('agent', agent.AgentRAID),
+                            ('no-raid', noop.NoRAID)]:
+            node = obj_utils.create_test_node(self.context,
+                                              uuid=uuidutils.generate_uuid(),
+                                              driver='ilo5',
+                                              raid_interface=iface)
+            with task_manager.acquire(self.context, node.id) as task:
+                self.assertIsInstance(task.driver.raid, impl)
